@@ -18,7 +18,6 @@
  */
 
 #include <standard/vclxaccessibletextcomponent.hxx>
-#include <toolkit/helper/macros.hxx>
 #include <toolkit/helper/convert.hxx>
 #include <helper/characterattributeshelper.hxx>
 
@@ -26,7 +25,6 @@
 #include <com/sun/star/datatransfer/clipboard/XClipboard.hpp>
 #include <com/sun/star/datatransfer/clipboard/XFlushableClipboard.hpp>
 #include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
-#include <cppuhelper/typeprovider.hxx>
 #include <vcl/window.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/unohelp2.hxx>
@@ -34,8 +32,6 @@
 #include <vcl/settings.hxx>
 #include <i18nlangtag/languagetag.hxx>
 
-#include <vector>
-
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::lang;
