@@ -20,6 +20,8 @@
 #include <config_features.h>
 
 #include <math.h>
+
+#include <o3tl/float_int_conversion.hxx>
 #include <tools/debug.hxx>
 #include <tools/stream.hxx>
 #include <sal/log.hxx>
@@ -155,8 +157,7 @@ void SbxValue::Clear()
                 {
                     SAL_INFO("basic.sbx", "Not at Parent-Prop - otherwise CyclicRef");
                     SbxVariable *pThisVar = dynamic_cast<SbxVariable*>( this );
-                    bool bParentProp = pThisVar && static_cast<sal_uInt16>(pThisVar->GetUserData()) ==
-                        5345;
+                    bool bParentProp = pThisVar && (pThisVar->GetUserData() & 0xFFFF) == 5345;
                     if ( !bParentProp )
                         aData.pObj->ReleaseRef();
                 }
@@ -477,8 +478,7 @@ bool SbxValue::Put( const SbxValues& rVal )
                             }
                             SAL_INFO("basic.sbx", "Not at Parent-Prop - otherwise CyclicRef");
                             SbxVariable *pThisVar = dynamic_cast<SbxVariable*>( this );
-                            bool bParentProp = pThisVar && static_cast<sal_uInt16>(pThisVar->GetUserData()) ==
-                                5345;
+                            bool bParentProp = pThisVar && (pThisVar->GetUserData() & 0xFFFF) == 5345;
                             if ( !bParentProp )
                                 p->aData.pObj->AddFirstRef();
                         }
@@ -690,11 +690,6 @@ bool SbxValue::ImpIsNumeric( bool bOnlyIntntl ) const
             || ( t >= SbxCHAR && t <= SbxUINT );
 }
 
-SbxClassType SbxValue::GetClass() const
-{
-    return SbxClassType::Value;
-}
-
 SbxDataType SbxValue::GetType() const
 {
     return SbxDataType( aData.eType & 0x0FFF );
@@ -738,8 +733,8 @@ bool SbxValue::SetType( SbxDataType t )
                     {
                         SAL_WARN("basic.sbx", "Not at Parent-Prop - otherwise CyclicRef");
                         SbxVariable *pThisVar = dynamic_cast<SbxVariable*>( this );
-                        sal_uInt16 nSlotId = pThisVar
-                                    ? static_cast<sal_uInt16>(pThisVar->GetUserData())
+                        sal_uInt32 nSlotId = pThisVar
+                                    ? pThisVar->GetUserData() & 0xFFFF
                                     : 0;
                         DBG_ASSERT( nSlotId != 5345 || pThisVar->GetName() == "Parent",
                                     "SID_PARENTOBJECT is not named 'Parent'" );
@@ -981,43 +976,40 @@ bool SbxValue::Compute( SbxOperator eOp, const SbxValue& rOp )
         {
             aL.eType = aR.eType = SbxDECIMAL;
             bDecimal = true;
-            if( rOp.Get( aR ) )
+            if( rOp.Get( aR ) && Get( aL ) )
             {
-                if( Get( aL ) )
+                if( aL.pDecimal && aR.pDecimal )
                 {
-                    if( aL.pDecimal && aR.pDecimal )
+                    bool bOk = true;
+                    switch( eOp )
                     {
-                        bool bOk = true;
-                        switch( eOp )
-                        {
-                            case SbxMUL:
-                                bOk = ( *(aL.pDecimal) *= *(aR.pDecimal) );
-                                break;
-                            case SbxDIV:
-                                if( aR.pDecimal->isZero() )
-                                    SetError( ERRCODE_BASIC_ZERODIV );
-                                else
-                                    bOk = ( *(aL.pDecimal) /= *(aR.pDecimal) );
-                                break;
-                            case SbxPLUS:
-                                bOk = ( *(aL.pDecimal) += *(aR.pDecimal) );
-                                break;
-                            case SbxMINUS:
-                                bOk = ( *(aL.pDecimal) -= *(aR.pDecimal) );
-                                break;
-                            case SbxNEG:
-                                bOk = ( aL.pDecimal->neg() );
-                                break;
-                            default:
-                                SetError( ERRCODE_BASIC_BAD_ARGUMENT );
-                        }
-                        if( !bOk )
-                            SetError( ERRCODE_BASIC_MATH_OVERFLOW );
-                    }
-                    else
-                    {
-                        SetError( ERRCODE_BASIC_CONVERSION );
+                        case SbxMUL:
+                            bOk = ( *(aL.pDecimal) *= *(aR.pDecimal) );
+                            break;
+                        case SbxDIV:
+                            if( aR.pDecimal->isZero() )
+                                SetError( ERRCODE_BASIC_ZERODIV );
+                            else
+                                bOk = ( *(aL.pDecimal) /= *(aR.pDecimal) );
+                            break;
+                        case SbxPLUS:
+                            bOk = ( *(aL.pDecimal) += *(aR.pDecimal) );
+                            break;
+                        case SbxMINUS:
+                            bOk = ( *(aL.pDecimal) -= *(aR.pDecimal) );
+                            break;
+                        case SbxNEG:
+                            bOk = ( aL.pDecimal->neg() );
+                            break;
+                        default:
+                            SetError( ERRCODE_BASIC_BAD_ARGUMENT );
                     }
+                    if( !bOk )
+                        SetError( ERRCODE_BASIC_MATH_OVERFLOW );
+                }
+                else
+                {
+                    SetError( ERRCODE_BASIC_CONVERSION );
                 }
             }
         }
@@ -1043,7 +1035,8 @@ bool SbxValue::Compute( SbxOperator eOp, const SbxValue& rOp )
                             }
                             // second overflow check: see if unscaled product overflows - if so use doubles
                             dTest = static_cast<double>(aL.nInt64) * static_cast<double>(aR.nInt64);
-                            if( dTest < SAL_MIN_INT64 || SAL_MAX_INT64 < dTest)
+                            if( !(o3tl::convertsToAtLeast(dTest, SAL_MIN_INT64)
+                                  && o3tl::convertsToAtMost(dTest, SAL_MAX_INT64)))
                             {
                                 aL.nInt64 = static_cast<sal_Int64>( dTest / double(CURRENCY_FACTOR) );
                                 break;
@@ -1070,7 +1063,8 @@ bool SbxValue::Compute( SbxOperator eOp, const SbxValue& rOp )
                             }
                             // second overflow check: see if scaled dividend overflows - if so use doubles
                             dTest = static_cast<double>(aL.nInt64) * double(CURRENCY_FACTOR);
-                            if( dTest < SAL_MIN_INT64 || SAL_MAX_INT64 < dTest)
+                            if( !(o3tl::convertsToAtLeast(dTest, SAL_MIN_INT64)
+                                  && o3tl::convertsToAtMost(dTest, SAL_MAX_INT64)))
                             {
                                 aL.nInt64 = static_cast<sal_Int64>(dTest / static_cast<double>(aR.nInt64));
                                 break;
