@@ -27,6 +27,8 @@
 #include <AxisHelper.hxx>
 #include <ObjectNameProvider.hxx>
 
+#include <comphelper/servicehelper.hxx>
+
 using ::com::sun::star::uno::Reference;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::chart2;
@@ -40,7 +42,7 @@ InsertErrorBarsDialog::InsertErrorBarsDialog(
     ErrorBarResources::tErrorBarType eType /* = ErrorBarResources::ERROR_BAR_Y */ )
         : GenericDialogController(pParent, "modules/schart/ui/dlg_InsertErrorBars.ui", "dlg_InsertErrorBars")
         , m_apErrorBarResources( new ErrorBarResources(
-                                   m_xBuilder.get(), TabPageParent(m_xDialog.get(), nullptr), rMyAttrs,
+                                   m_xBuilder.get(), this, rMyAttrs,
                                    /* bNoneAvailable = */ true, eType ))
 {
     ObjectType objType = eType == ErrorBarResources::ERROR_BAR_Y ? OBJECTTYPE_DATA_ERRORS_Y : OBJECTTYPE_DATA_ERRORS_X;
@@ -67,7 +69,7 @@ double InsertErrorBarsDialog::getAxisMinorStepWidthForErrorBarDecimals(
 {
     double fStepWidth = 0.001;
 
-    ExplicitValueProvider* pExplicitValueProvider( ExplicitValueProvider::getExplicitValueProvider(xChartView) );
+    ExplicitValueProvider* pExplicitValueProvider( comphelper::getUnoTunnelImplementation<ExplicitValueProvider>(xChartView) );
     if( pExplicitValueProvider )
     {
         Reference< XAxis > xAxis;
