@@ -110,9 +110,9 @@ void ItemConverter::FillItemSet( SfxItemSet & rOutItemSet ) const
                             rOutItemSet.Put( std::move(pItem) );
                         }
                     }
-                    catch( const beans::UnknownPropertyException &ex )
+                    catch( const beans::UnknownPropertyException & )
                     {
-                        SAL_WARN( "chart2", ex << " - unknown Property: " << aProperty.first);
+                        TOOLS_WARN_EXCEPTION( "chart2", "unknown Property: " << aProperty.first);
                     }
                     catch( const uno::Exception & )
                     {
@@ -154,11 +154,10 @@ bool ItemConverter::ApplyItemSet( const SfxItemSet & rItemSet )
 
     bool bItemsChanged = false;
     SfxItemIter aIter( rItemSet );
-    const SfxPoolItem * pItem = aIter.FirstItem();
     tPropertyNameWithMemberId aProperty;
     uno::Any aValue;
 
-    while( pItem )
+    for (const SfxPoolItem* pItem = aIter.GetCurItem(); pItem; pItem = aIter.NextItem())
     {
         if( rItemSet.GetItemState( pItem->Which(), false ) == SfxItemState::SET )
         {
@@ -174,13 +173,13 @@ bool ItemConverter::ApplyItemSet( const SfxItemSet & rItemSet )
                         bItemsChanged = true;
                     }
                 }
-                catch( const beans::UnknownPropertyException &ex )
+                catch( const beans::UnknownPropertyException & )
                 {
-                    SAL_WARN( "chart2", ex << " - unknown Property: " << aProperty.first);
+                    TOOLS_WARN_EXCEPTION( "chart2", "unknown Property: " << aProperty.first);
                 }
-                catch( const uno::Exception &ex )
+                catch( const uno::Exception & )
                 {
-                    SAL_WARN( "chart2", ex );
+                    TOOLS_WARN_EXCEPTION( "chart2", "" );
                 }
             }
             else
@@ -188,7 +187,6 @@ bool ItemConverter::ApplyItemSet( const SfxItemSet & rItemSet )
                 bItemsChanged = ApplySpecialItem( pItem->Which(), rItemSet ) || bItemsChanged;
             }
         }
-        pItem = aIter.NextItem();
     }
 
     return bItemsChanged;
