@@ -206,9 +206,9 @@ public:
             throw ParseError( "Not enough arguments for binary operator" );
 
         // retrieve arguments
-        std::shared_ptr<ExpressionNode> pSecondArg( rNodeStack.top() );
+        std::shared_ptr<ExpressionNode> pSecondArg( std::move(rNodeStack.top()) );
         rNodeStack.pop();
-        std::shared_ptr<ExpressionNode> pFirstArg( rNodeStack.top() );
+        std::shared_ptr<ExpressionNode> pFirstArg( std::move(rNodeStack.top()) );
         rNodeStack.pop();
 
         // create combined ExpressionNode
@@ -257,7 +257,7 @@ public:
             throw ParseError( "Not enough arguments for unary operator" );
 
         // retrieve arguments
-        std::shared_ptr<ExpressionNode> pArg( rNodeStack.top() );
+        std::shared_ptr<ExpressionNode> pArg( std::move(rNodeStack.top()) );
         rNodeStack.pop();
 
         rNodeStack.push( std::shared_ptr<ExpressionNode>( new UnaryFunctionExpression( pArg ) ) );
