@@ -41,6 +41,7 @@
 #include <comphelper/processfactory.hxx>
 #include <unotools/confignode.hxx>
 #include <osl/diagnose.h>
+#include <svtools/miscopt.hxx>
 #include <sal/log.hxx>
 #include <dbwizsetup.hxx>
 
@@ -146,6 +147,9 @@ namespace dbaui
                 DisplayedTypes aDisplayedTypes;
 
                 ::dbaccess::ODsnTypeCollection::TypeIterator aEnd = m_pCollection->end();
+
+                SvtMiscOptions aMiscOptions;
+
                 for (   ::dbaccess::ODsnTypeCollection::TypeIterator aTypeLoop =  m_pCollection->begin();
                         aTypeLoop != aEnd;
                         ++aTypeLoop
@@ -158,6 +162,8 @@ namespace dbaui
                         if (m_xEmbeddedDBType->find_text(sDisplayName) == -1 &&
                             dbaccess::ODsnTypeCollection::isEmbeddedDatabase(sURLPrefix))
                         {
+                            if( !aMiscOptions.IsExperimentalMode() && sURLPrefix.startsWith("sdbc:embedded:firebird") )
+                                continue;
                             aDisplayedTypes.emplace_back( sURLPrefix, sDisplayName );
                         }
                     }
