@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "TableConnectionData.hxx"
+#include <TableConnectionData.hxx>
 #include <osl/diagnose.h>
 
 using namespace dbaui;
@@ -74,12 +74,8 @@ OTableConnectionData& OTableConnectionData::operator=( const OTableConnectionDat
     ResetConnLines();
 
     // and copy
-    const OConnectionLineDataVec& rLineData = rConnData.GetConnLineDataList();
-
-    OConnectionLineDataVec::const_iterator aIter = rLineData.begin();
-    OConnectionLineDataVec::const_iterator aEnd = rLineData.end();
-    for(;aIter != aEnd;++aIter)
-        m_vConnLineData.push_back(new OConnectionLineData(**aIter));
+    for (auto const& elem : rConnData.GetConnLineDataList())
+        m_vConnLineData.push_back(new OConnectionLineData(*elem));
 
     return *this;
 }
@@ -98,7 +94,7 @@ void OTableConnectionData::SetConnLine( sal_uInt16 nIndex, const OUString& rSour
     }
 
     OConnectionLineDataRef pConnLineData = m_vConnLineData[nIndex];
-    OSL_ENSURE(pConnLineData != nullptr, "OTableConnectionData::SetConnLine : habe ungueltiges LineData-Objekt");
+    OSL_ENSURE(pConnLineData != nullptr, "OTableConnectionData::SetConnLine : have invalid LineData object");
 
     pConnLineData->SetSourceFieldName( rSourceFieldName );
     pConnLineData->SetDestFieldName( rDestFieldName );
@@ -106,21 +102,16 @@ void OTableConnectionData::SetConnLine( sal_uInt16 nIndex, const OUString& rSour
 
 bool OTableConnectionData::AppendConnLine( const OUString& rSourceFieldName, const OUString& rDestFieldName )
 {
-    OConnectionLineDataVec::const_iterator aIter = m_vConnLineData.begin();
-    OConnectionLineDataVec::const_iterator aEnd = m_vConnLineData.end();
-    for(;aIter != aEnd;++aIter)
+    for (auto const& elem : m_vConnLineData)
     {
-        if((*aIter)->GetDestFieldName() == rDestFieldName && (*aIter)->GetSourceFieldName() == rSourceFieldName)
-            break;
+        if(elem->GetDestFieldName() == rDestFieldName && elem->GetSourceFieldName() == rSourceFieldName)
+            return true;
     }
-    if(aIter == aEnd)
-    {
-        OConnectionLineDataRef pNew = new OConnectionLineData(rSourceFieldName, rDestFieldName);
-        if (!pNew.is())
-            return false;
+    OConnectionLineDataRef pNew = new OConnectionLineData(rSourceFieldName, rDestFieldName);
+    if (!pNew.is())
+        return false;
 
-        m_vConnLineData.push_back(pNew);
-    }
+    m_vConnLineData.push_back(pNew);
     return true;
 }
 
@@ -129,11 +120,6 @@ void OTableConnectionData::ResetConnLines()
     OConnectionLineDataVec().swap(m_vConnLineData);
 }
 
-OConnectionLineDataRef OTableConnectionData::CreateLineDataObj()
-{
-    return new OConnectionLineData();
-}
-
 OTableConnectionData* OTableConnectionData::NewInstance() const
 {
     return new OTableConnectionData();
