@@ -57,7 +57,7 @@ public:
     // XServiceInfo
     virtual OUString SAL_CALL getImplementationName() override
     {
-        return OUString("com.sun.star.comp.framework.ObjectMenuController");
+        return "com.sun.star.comp.framework.ObjectMenuController";
     }
 
     virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName) override
@@ -89,7 +89,7 @@ ObjectMenuController::ObjectMenuController( const css::uno::Reference< css::uno:
 void ObjectMenuController::fillPopupMenu( const Sequence< css::embed::VerbDescriptor >& rVerbCommandSeq, Reference< css::awt::XPopupMenu > const & rPopupMenu )
 {
     const css::embed::VerbDescriptor* pVerbCommandArray = rVerbCommandSeq.getConstArray();
-    VCLXPopupMenu*                    pPopupMenu        = static_cast<VCLXPopupMenu *>(VCLXMenu::GetImplementation( rPopupMenu ));
+    VCLXPopupMenu*                    pPopupMenu        = static_cast<VCLXPopupMenu *>(comphelper::getUnoTunnelImplementation<VCLXMenu>( rPopupMenu ));
     PopupMenu*                        pVCLPopupMenu     = nullptr;
 
     SolarMutexGuard aSolarMutexGuard;
@@ -109,8 +109,7 @@ void ObjectMenuController::fillPopupMenu( const Sequence< css::embed::VerbDescri
                 m_xPopupMenu->insertItem( i+1, rVerb.VerbName, 0, i );
                 // use VCL popup menu pointer to set vital information that are not part of the awt implementation
 
-                OUString aCommand( aVerbCommand );
-                aCommand += OUString::number( rVerb.VerbID );
+                OUString aCommand = aVerbCommand + OUString::number( rVerb.VerbID );
                 pVCLPopupMenu->SetItemCommand( i+1, aCommand ); // Store verb command
             }
         }
