@@ -34,7 +34,6 @@
  *************************************************************************/
 
 #include "filterdetect.hxx"
-#include <osl/diagnose.h>
 #include <com/sun/star/io/XActiveDataSource.hpp>
 #include <com/sun/star/io/XOutputStream.hpp>
 #include <com/sun/star/io/XInputStream.hpp>
@@ -95,7 +94,7 @@ OUString SAL_CALL FilterDetect::detect(Sequence< PropertyValue >& aArguments )
 
     if (!xInStream.is())
     {
-        // open the stream if it was not suplied by the framework
+        // open the stream if it was not supplied by the framework
         Reference< XSimpleFileAccess3 > xSFI(SimpleFileAccess::create(mxContext));
         if (sURL.getLength() > 0)
         {
@@ -114,7 +113,7 @@ OUString SAL_CALL FilterDetect::detect(Sequence< PropertyValue >& aArguments )
     }
 
     // flatxml starts with an office:document element. this element
-    // conatains a clas="..." attribute by which we can deduct the
+    // contains a class="..." attribute by which we can deduct the
     // type of document that is to be loaded
 
     // WARNING:
