@@ -17,20 +17,19 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "oox/drawingml/textfont.hxx"
+#include <drawingml/textfont.hxx>
 #include <com/sun/star/awt/FontFamily.hpp>
 #include <com/sun/star/awt/FontPitch.hpp>
-#include "oox/drawingml/theme.hxx"
-#include "oox/core/xmlfilterbase.hxx"
-#include "oox/helper/attributelist.hxx"
+#include <oox/drawingml/theme.hxx>
+#include <oox/core/xmlfilterbase.hxx>
+#include <oox/helper/attributelist.hxx>
+#include <oox/token/tokens.hxx>
 
 using ::oox::core::XmlFilterBase;
 
 namespace oox {
 namespace drawingml {
 
-
-
 namespace {
 
 sal_Int16 lclGetFontPitch( sal_Int32 nOoxValue )
@@ -49,8 +48,6 @@ sal_Int16 lclGetFontFamily( sal_Int32 nOoxValue )
 
 } // namespace
 
-
-
 TextFont::TextFont() :
     mnPitch( 0 ),
     mnCharset( WINDOWS_CHARSET_ANSI )
@@ -68,7 +65,7 @@ void TextFont::setAttributes( const AttributeList& rAttribs )
 void TextFont::setAttributes( const OUString& sFontName )
 {
     maTypeface = sFontName;
-    maPanose = OUString();
+    maPanose.clear();
     mnPitch = 0;
     mnCharset = WINDOWS_CHARSET_DEFAULT;
 }
@@ -95,8 +92,6 @@ bool TextFont::implGetFontData( OUString& rFontName, sal_Int16& rnFontPitch, sal
     return !rFontName.isEmpty();
 }
 
-
-
 } // namespace drawingml
 } // namespace oox
 
