@@ -21,7 +21,6 @@ package mod._sw;
 //API Interfaces
 import java.io.PrintWriter;
 
-import lib.StatusException;
 import lib.TestCase;
 import lib.TestEnvironment;
 import lib.TestParameters;
@@ -72,18 +71,14 @@ public class SwXTextDefaults extends TestCase {
      */
     @Override
     protected TestEnvironment createTestEnvironment(
-            TestParameters tParam, PrintWriter log) {
+            TestParameters tParam, PrintWriter log) throws Exception {
 
         XInterface oObj = null;
 
         XMultiServiceFactory docMSF = UnoRuntime.queryInterface(XMultiServiceFactory.class,xTextDoc);
 
-        try {
-            oObj = (XInterface)
-                docMSF.createInstance("com.sun.star.text.Defaults");
-        } catch (com.sun.star.uno.Exception e) {
-            throw new StatusException("Couldn't create Object",e);
-        }
+        oObj = (XInterface)
+            docMSF.createInstance("com.sun.star.text.Defaults");
 
         TestEnvironment tEnv = new TestEnvironment(oObj);
 
@@ -94,15 +89,10 @@ public class SwXTextDefaults extends TestCase {
     * Creates text document.
     */
     @Override
-    protected void initialize( TestParameters tParam, PrintWriter log ) {
+    protected void initialize( TestParameters tParam, PrintWriter log ) throws Exception {
         SOfficeFactory SOF = SOfficeFactory.getFactory( tParam.getMSF() );
-        try {
-            log.println( "creating a textdocument" );
-            xTextDoc = SOF.createTextDoc( null );
-        } catch ( com.sun.star.uno.Exception e ) {
-            e.printStackTrace( log );
-            throw new StatusException( "Couldn't create document", e );
-        }
+        log.println( "creating a textdocument" );
+        xTextDoc = SOF.createTextDoc( null );
     }
 
     /**
