@@ -628,11 +628,11 @@ void ScDBData::ExtendDataArea(const ScDocument* pDoc)
     SCCOL nOldCol1 = nStartCol, nOldCol2 = nEndCol;
     SCROW nOldEndRow = nEndRow;
     pDoc->GetDataArea(nTable, nStartCol, nStartRow, nEndCol, nEndRow, false, true);
-    // nOldEndRow==MAXROW may easily happen when selecting whole columns and
+    // nOldEndRow==rDoc.MaxRow() may easily happen when selecting whole columns and
     // setting an AutoFilter (i.e. creating an anonymous database-range). We
     // certainly don't want to iterate over nearly a million empty cells, but
     // keep only an intentionally user selected range.
-    if (nOldEndRow < MAXROW && nEndRow < nOldEndRow)
+    if (nOldEndRow < pDoc->MaxRow() && nEndRow < nOldEndRow)
         nEndRow = nOldEndRow;
     if (nStartCol != nOldCol1 || nEndCol != nOldCol2)
     {
@@ -906,7 +906,7 @@ void ScDBData::Notify( const SfxHint& rHint )
             // Only one cell of a range is broadcasted per area listener if
             // multiple cells are affected. Expand the range to what this is
             // listening to. Broadcasted address outside should not happen,
-            // but.. let it trigger a refresh if.
+            // but... let it trigger a refresh if.
             ScRange aHeaderRange( GetHeaderArea());
             if (aHeaderRange.IsValid())
             {
@@ -1167,7 +1167,7 @@ bool ScDBCollection::NamedDBs::insert(std::unique_ptr<ScDBData> pData)
         initInserted(p);
 
         /* TODO: shouldn't the import refresh not be setup for
-         * clipboard/undo documents? It was already like this before.. */
+         * clipboard/undo documents? It was already like this before... */
         if (p->HasImportParam() && !p->HasImportSelection())
         {
             p->SetRefreshHandler(mrParent.GetRefreshHandler());
@@ -1427,7 +1427,7 @@ void ScDBCollection::DeleteOnTab( SCTAB nTab )
     }
 
     // Delete them all.
-    for (auto& rIter : v)
+    for (const auto& rIter : v)
         maNamedDBs.erase(rIter);
 
     maAnonDBs.deleteOnTab(nTab);
