@@ -19,9 +19,7 @@
 
 #include <spelldialog.hxx>
 
-#include <sfx2/app.hxx>
 #include <sfx2/bindings.hxx>
-#include <sfx2/dispatch.hxx>
 #include <svx/svxids.hrc>
 #include <editeng/editstat.hxx>
 #include <editeng/editview.hxx>
@@ -194,7 +192,7 @@ void ScSpellDialogChildWindow::Init()
             ScEditableTester aTester( mpDoc, rMarkData );
             if( !aTester.IsEditable() )
             {
-                // #i85751# Don't show a ErrorMessage here, because the vcl
+                // #i85751# Don't show an ErrorMessage here, because the vcl
                 // parent of the InfoBox is not fully initialized yet.
                 // This leads to problems in the modality behaviour of the
                 // ScSpellDialogChildWindow.
