@@ -29,9 +29,10 @@
 #include <vcl/help.hxx>
 #include <svx/bmpmask.hxx>
 #include <svx/svdotext.hxx>
-#include <sfx2/app.hxx>
+#include <svx/ImageMapInfo.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/bindings.hxx>
+#include <sfx2/sfxhelp.hxx>
 #include <svx/svdpagv.hxx>
 #include <vcl/imapobj.hxx>
 #include <svx/svxids.hrc>
@@ -39,12 +40,10 @@
 #include <svx/scene3d.hxx>
 #include <sfx2/viewfrm.hxx>
 
-#include <anminfo.hxx>
 #include <strings.hrc>
 
 
 #include <sdmod.hxx>
-#include <GraphicDocShell.hxx>
 #include <fudraw.hxx>
 #include <ViewShell.hxx>
 #include <FrameView.hxx>
@@ -53,12 +52,9 @@
 #include <drawdoc.hxx>
 #include <DrawDocShell.hxx>
 #include <sdresid.hxx>
-#include <drawview.hxx>
 #include <fusel.hxx>
 #include <vcl/weld.hxx>
-#include <slideshow.hxx>
 #include <svx/sdrhittesthelper.hxx>
-#include <unotools/securityoptions.hxx>
 
 using namespace ::com::sun::star;
 
@@ -554,15 +550,19 @@ void FuDraw::ForcePointer(const MouseEvent* pMEvt)
                 }
             }
 
-            if (pObj && pMEvt && !pMEvt->IsMod2() && dynamic_cast< const   FuSelection *>( this ) !=  nullptr)
+            if (pObj && pMEvt && !pMEvt->IsMod2()
+                && dynamic_cast<const FuSelection*>(this) != nullptr)
             {
-                // test for animation or ImageMap
+                // test for ImageMap
                 bDefPointer = !SetPointer(pObj, aPnt);
 
-                if (bDefPointer && (dynamic_cast< const SdrObjGroup *>( pObj ) != nullptr || dynamic_cast< const E3dScene* >(pObj) !=  nullptr))
+                if (bDefPointer
+                    && (dynamic_cast<const SdrObjGroup*>(pObj) != nullptr
+                        || dynamic_cast<const E3dScene*>(pObj) != nullptr))
                 {
                     // take a glance into the group
-                    pObj = mpView->PickObj(aPnt, mpView->getHitTolLog(), pPV, SdrSearchOptions::ALSOONMASTER | SdrSearchOptions::DEEP);
+                    pObj = mpView->PickObj(aPnt, mpView->getHitTolLog(), pPV,
+                                           SdrSearchOptions::ALSOONMASTER | SdrSearchOptions::DEEP);
                     if (pObj)
                         bDefPointer = !SetPointer(pObj, aPnt);
                 }
@@ -578,91 +578,49 @@ void FuDraw::ForcePointer(const MouseEvent* pMEvt)
 }
 
 /**
- * Set cursor for animation or imagemap
+ * Set cursor to pointer when in clickable area of an ImageMap
+ *
+ * @return True when pointer was set
  */
-bool FuDraw::SetPointer(SdrObject* pObj, const Point& rPos)
+bool FuDraw::SetPointer(const SdrObject* pObj, const Point& rPos)
 {
-    bool bSet = false;
+    bool bImageMapInfo = SvxIMapInfo::GetIMapInfo(pObj) != nullptr;
 
-    bool bAnimationInfo = dynamic_cast< const GraphicDocShell *>( mpDocSh ) ==  nullptr &&
-                          SdDrawDocument::GetAnimationInfo(pObj);
+    if (!bImageMapInfo)
+        return false;
 
-    bool bImageMapInfo = false;
+    const SdrLayerIDSet* pVisiLayer = &mpView->GetSdrPageView()->GetVisibleLayers();
+    sal_uInt16 nHitLog(sal_uInt16(mpWindow->PixelToLogic(Size(HITPIX, 0)).Width()));
+    long n2HitLog(nHitLog * 2);
+    Point aHitPosR(rPos);
+    Point aHitPosL(rPos);
+    Point aHitPosT(rPos);
+    Point aHitPosB(rPos);
 
-    if (!bAnimationInfo)
-        bImageMapInfo = SdDrawDocument::GetIMapInfo(pObj) != nullptr;
+    aHitPosR.AdjustX(n2HitLog);
+    aHitPosL.AdjustX(-n2HitLog);
+    aHitPosT.AdjustY(n2HitLog);
+    aHitPosB.AdjustY(-n2HitLog);
 
-    if (bAnimationInfo || bImageMapInfo)
+    if (!pObj->IsClosedObj()
+        || (SdrObjectPrimitiveHit(*pObj, aHitPosR, nHitLog, *mpView->GetSdrPageView(), pVisiLayer,
+                                  false)
+            && SdrObjectPrimitiveHit(*pObj, aHitPosL, nHitLog, *mpView->GetSdrPageView(),
+                                     pVisiLayer, false)
+            && SdrObjectPrimitiveHit(*pObj, aHitPosT, nHitLog, *mpView->GetSdrPageView(),
+                                     pVisiLayer, false)
+            && SdrObjectPrimitiveHit(*pObj, aHitPosB, nHitLog, *mpView->GetSdrPageView(),
+                                     pVisiLayer, false)))
     {
-        const SdrLayerIDSet* pVisiLayer = &mpView->GetSdrPageView()->GetVisibleLayers();
-        sal_uInt16 nHitLog(sal_uInt16 (mpWindow->PixelToLogic(Size(HITPIX,0)).Width()));
-        long  n2HitLog(nHitLog * 2);
-        Point aHitPosR(rPos);
-        Point aHitPosL(rPos);
-        Point aHitPosT(rPos);
-        Point aHitPosB(rPos);
-
-        aHitPosR.AdjustX(n2HitLog );
-        aHitPosL.AdjustX( -n2HitLog );
-        aHitPosT.AdjustY(n2HitLog );
-        aHitPosB.AdjustY( -n2HitLog );
-
-        if ( !pObj->IsClosedObj() ||
-            ( SdrObjectPrimitiveHit(*pObj, aHitPosR, nHitLog, *mpView->GetSdrPageView(), pVisiLayer, false) &&
-              SdrObjectPrimitiveHit(*pObj, aHitPosL, nHitLog, *mpView->GetSdrPageView(), pVisiLayer, false) &&
-              SdrObjectPrimitiveHit(*pObj, aHitPosT, nHitLog, *mpView->GetSdrPageView(), pVisiLayer, false) &&
-              SdrObjectPrimitiveHit(*pObj, aHitPosB, nHitLog, *mpView->GetSdrPageView(), pVisiLayer, false)))
+        // hit inside the object (without margin) or open object
+        if (SvxIMapInfo::GetHitIMapObject(pObj, rPos))
         {
-            /**********************************************************
-            * hit inside the object (without margin) or open object
-            ********************************************************/
-
-            if (bAnimationInfo)
-            {
-                /******************************************************
-                * Click-Action
-                ******************************************************/
-                SdAnimationInfo* pInfo = SdDrawDocument::GetAnimationInfo(pObj);
-
-                if(( dynamic_cast< const DrawView *>( mpView ) !=  nullptr &&
-                      (pInfo->meClickAction == presentation::ClickAction_BOOKMARK  ||
-                       pInfo->meClickAction == presentation::ClickAction_DOCUMENT  ||
-                       pInfo->meClickAction == presentation::ClickAction_PREVPAGE  ||
-                       pInfo->meClickAction == presentation::ClickAction_NEXTPAGE  ||
-                       pInfo->meClickAction == presentation::ClickAction_FIRSTPAGE ||
-                       pInfo->meClickAction == presentation::ClickAction_LASTPAGE  ||
-                       pInfo->meClickAction == presentation::ClickAction_VERB      ||
-                       pInfo->meClickAction == presentation::ClickAction_PROGRAM   ||
-                       pInfo->meClickAction == presentation::ClickAction_MACRO     ||
-                       pInfo->meClickAction == presentation::ClickAction_SOUND))
-                                                                    ||
-                    ( dynamic_cast< const DrawView *>( mpView ) !=  nullptr &&
-                        SlideShow::IsRunning( mpViewShell->GetViewShellBase() )   &&
-                         (pInfo->meClickAction == presentation::ClickAction_VANISH            ||
-                          pInfo->meClickAction == presentation::ClickAction_INVISIBLE         ||
-                          pInfo->meClickAction == presentation::ClickAction_STOPPRESENTATION ||
-                         (pInfo->mbActive &&
-                          ( pInfo->meEffect != presentation::AnimationEffect_NONE ||
-                            pInfo->meTextEffect != presentation::AnimationEffect_NONE )))))
-                    {
-                        // Animation object
-                        bSet = true;
-                        mpWindow->SetPointer(PointerStyle::RefHand);
-                    }
-            }
-            else if (bImageMapInfo &&
-                     SdDrawDocument::GetHitIMapObject(pObj, rPos))
-            {
-                /******************************************************
-                * ImageMap
-                ******************************************************/
-                bSet = true;
-                mpWindow->SetPointer(PointerStyle::RefHand);
-            }
+            mpWindow->SetPointer(PointerStyle::RefHand);
+            return true;
         }
     }
 
-    return bSet;
+    return false;
 }
 
 /**
@@ -767,186 +725,52 @@ bool FuDraw::RequestHelp(const HelpEvent& rHEvt)
     return bReturn;
 }
 
-bool FuDraw::SetHelpText(SdrObject* pObj, const Point& rPosPixel, const SdrViewEvent& rVEvt)
+bool FuDraw::SetHelpText(const SdrObject* pObj, const Point& rPosPixel, const SdrViewEvent& rVEvt)
 {
-    bool bSet = false;
     OUString aHelpText;
     Point aPos(mpWindow->PixelToLogic(mpWindow->ScreenToOutputPixel(rPosPixel)));
+    IMapObject* pIMapObj = SvxIMapInfo::GetHitIMapObject(pObj, aPos);
 
-    // URL for IMapObject underneath pointer is help text
-    if ( SdDrawDocument::GetIMapInfo(pObj) )
+    if (!rVEvt.pURLField && !pIMapObj)
+        return false;
+
+    OUString aURL;
+    if (rVEvt.pURLField)
+        aURL = INetURLObject::decode(rVEvt.pURLField->GetURL(),
+                                     INetURLObject::DecodeMechanism::WithCharset);
+    else if (pIMapObj)
     {
-        IMapObject* pIMapObj = SdDrawDocument::GetHitIMapObject(pObj, aPos);
-
-        if ( pIMapObj )
-        {
-            // show name
-            aHelpText = pIMapObj->GetAltText();
-
-            if (aHelpText.isEmpty())
-            {
-                // show url if no name is available
-                aHelpText = INetURLObject::decode( pIMapObj->GetURL(), INetURLObject::DecodeMechanism::WithCharset );
-            }
-        }
+        aURL = pIMapObj->GetAltText() +
+            " (" +
+            INetURLObject::decode(pIMapObj->GetURL(),
+                                        INetURLObject::DecodeMechanism::WithCharset) +
+            ")";
     }
-    else if (rVEvt.pURLField)
-    {
-        /**************************************************************
-        * URL-Field
-        **************************************************************/
-        OUString aURL = INetURLObject::decode(rVEvt.pURLField->GetURL(), INetURLObject::DecodeMechanism::WithCharset);
+    else
+        return false;
 
-        SvtSecurityOptions aSecOpt;
-        if (aSecOpt.IsOptionSet(SvtSecurityOptions::EOption::CtrlClickHyperlink))
-        {
-            // Hint about Ctrl-click to open hyperlink, but need to detect "Ctrl" key for MacOs
-            vcl::KeyCode aCode(KEY_SPACE);
-            vcl::KeyCode aModifiedCode(KEY_SPACE, KEY_MOD1);
-            OUString aModStr(aModifiedCode.GetName());
-            aModStr = aModStr.replaceFirst(aCode.GetName(), "");
-            aModStr = aModStr.replaceAll("+", "");
+    aHelpText = SfxHelp::GetURLHelpText(aURL);
 
-            OUString aCtrlClickHlinkStr = SdResId(STR_CTRLCLICKHYPERLINK);
+    if (aHelpText.isEmpty())
+        return false;
 
-            aCtrlClickHlinkStr = aCtrlClickHlinkStr.replaceAll("%s", aModStr);
+    ::tools::Rectangle aLogicPix = mpWindow->LogicToPixel(pObj->GetLogicRect());
+    ::tools::Rectangle aScreenRect(mpWindow->OutputToScreenPixel(aLogicPix.TopLeft()),
+                            mpWindow->OutputToScreenPixel(aLogicPix.BottomRight()));
 
-            aHelpText = aCtrlClickHlinkStr + aURL;
-        }
-        else
-        {
-            // Hint about just clicking hyperlink
-            aHelpText = SdResId(STR_CLICKHYPERLINK) + aURL;
-        }
-    }
-    else if (dynamic_cast< GraphicDocShell *>( mpDocSh ) ==  nullptr && SdDrawDocument::GetAnimationInfo(pObj))
-    {
-        SdAnimationInfo* pInfo = SdDrawDocument::GetAnimationInfo(pObj);
+    if (Help::IsBalloonHelpEnabled())
+        Help::ShowBalloon( static_cast<vcl::Window*>(mpWindow), rPosPixel, aScreenRect, aHelpText);
+    else if (Help::IsQuickHelpEnabled())
+        Help::ShowQuickHelp( static_cast<vcl::Window*>(mpWindow), aScreenRect, aHelpText);
 
-        switch (pInfo->meClickAction)
-        {
-            case presentation::ClickAction_PREVPAGE:
-            {
-                // jump to the prior page
-                aHelpText = SdResId(STR_CLICK_ACTION_PREVPAGE);
-            }
-            break;
-
-            case presentation::ClickAction_NEXTPAGE:
-            {
-                // jump to the next page
-                aHelpText = SdResId(STR_CLICK_ACTION_NEXTPAGE);
-            }
-            break;
-
-            case presentation::ClickAction_FIRSTPAGE:
-            {
-                // jump to the first page
-                aHelpText = SdResId(STR_CLICK_ACTION_FIRSTPAGE);
-            }
-            break;
-
-            case presentation::ClickAction_LASTPAGE:
-            {
-                // jump to the last page
-                aHelpText = SdResId(STR_CLICK_ACTION_LASTPAGE);
-            }
-            break;
-
-            case presentation::ClickAction_BOOKMARK:
-            {
-                // jump to object/page
-                aHelpText = SdResId(STR_CLICK_ACTION_BOOKMARK)
-                    + ": "
-                    + INetURLObject::decode( pInfo->GetBookmark(), INetURLObject::DecodeMechanism::WithCharset );
-            }
-            break;
-
-            case presentation::ClickAction_DOCUMENT:
-            {
-                // jump to document (object/page)
-                aHelpText = SdResId(STR_CLICK_ACTION_DOCUMENT)
-                    + ": "
-                    + INetURLObject::decode( pInfo->GetBookmark(), INetURLObject::DecodeMechanism::WithCharset );
-            }
-            break;
-
-            case presentation::ClickAction_PROGRAM:
-            {
-                // execute program
-                aHelpText = SdResId(STR_CLICK_ACTION_PROGRAM)
-                    + ": "
-                    + INetURLObject::decode( pInfo->GetBookmark(), INetURLObject::DecodeMechanism::WithCharset );
-            }
-            break;
-
-            case presentation::ClickAction_MACRO:
-            {
-                // execute program
-                aHelpText = SdResId(STR_CLICK_ACTION_MACRO) + ": ";
-
-                if ( SfxApplication::IsXScriptURL( pInfo->GetBookmark() ) )
-                {
-                    aHelpText += pInfo->GetBookmark();
-                }
-                else
-                {
-                    OUString sBookmark( pInfo->GetBookmark() );
-                    sal_Int32 nIdx{ 0 };
-                    const OUString s0{ sBookmark.getToken( 0, '.', nIdx ) };
-                    const OUString s1{ sBookmark.getToken( 0, '.', nIdx ) };
-                    const OUString s2{ sBookmark.getToken( 0, '.', nIdx ) };
-                    aHelpText += s2 + "." + s1 + "." + s0;
-                }
-            }
-            break;
-
-            case presentation::ClickAction_SOUND:
-            {
-                // play-back sound
-                aHelpText = SdResId(STR_CLICK_ACTION_SOUND);
-            }
-            break;
-
-            case presentation::ClickAction_VERB:
-            {
-                // execute OLE-verb
-                aHelpText = SdResId(STR_CLICK_ACTION_VERB);
-            }
-            break;
-
-            case presentation::ClickAction_STOPPRESENTATION:
-            {
-                // quit presentation
-                aHelpText = SdResId(STR_CLICK_ACTION_STOPPRESENTATION);
-            }
-            break;
-            default:
-                break;
-        }
-    }
-
-    if (!aHelpText.isEmpty())
-    {
-        bSet = true;
-        ::tools::Rectangle aLogicPix = mpWindow->LogicToPixel(pObj->GetLogicRect());
-        ::tools::Rectangle aScreenRect(mpWindow->OutputToScreenPixel(aLogicPix.TopLeft()),
-                              mpWindow->OutputToScreenPixel(aLogicPix.BottomRight()));
-
-        if (Help::IsBalloonHelpEnabled())
-            Help::ShowBalloon( static_cast<vcl::Window*>(mpWindow), rPosPixel, aScreenRect, aHelpText);
-        else if (Help::IsQuickHelpEnabled())
-            Help::ShowQuickHelp( static_cast<vcl::Window*>(mpWindow), aScreenRect, aHelpText);
-    }
-
-    return bSet;
+    return true;
 }
 
 /** is called when the current function should be aborted. <p>
     This is used when a function gets a KEY_ESCAPE but can also
     be called directly.
 
-    @returns true if a active function was aborted
+    @returns true if an active function was aborted
 */
 bool FuDraw::cancel()
 {
