@@ -19,61 +19,48 @@
 
 #include <com/sun/star/ui/XDeck.hpp>
 #include <com/sun/star/ui/XPanel.hpp>
+#include <com/sun/star/frame/XController2.hpp>
 #include "SlideBackground.hxx"
-#include <TransitionPreset.hxx>
 #include <sdresid.hxx>
 #include <ViewShellBase.hxx>
 #include <FrameView.hxx>
 #include <DrawDocShell.hxx>
-#include <SlideSorterViewShell.hxx>
 #include <drawdoc.hxx>
 #include <sdpage.hxx>
-#include <filedlg.hxx>
 #include <sdmod.hxx>
 #include <optsitem.hxx>
 #include "PageMarginUtils.hxx"
 #include <strings.hrc>
 #include <pageformatpanel.hrc>
-#include "DocumentHelper.hxx"
-#include "MasterPagesSelector.hxx"
 #include <DrawViewShell.hxx>
-#include <DrawController.hxx>
-#include <com/sun/star/beans/XPropertySet.hpp>
-#include <svtools/controldims.hxx>
 #include <svx/colorbox.hxx>
-#include <svx/gallery.hxx>
 #include <svx/drawitem.hxx>
-#include <unotools/pathoptions.hxx>
+#include <svx/pageitem.hxx>
 #include <tools/urlobj.hxx>
-#include <sfx2/sidebar/Theme.hxx>
 #include <app.hrc>
 #include <editeng/paperinf.hxx>
 #include <svx/xflgrit.hxx>
 #include <svx/rulritem.hxx>
 #include <svx/svxids.hrc>
+#include <svx/xfillit0.hxx>
 #include <svx/xflclit.hxx>
 #include <svx/xgrad.hxx>
-#include <svx/xbitmap.hxx>
-#include <svx/xflbckit.hxx>
 #include <svx/xbtmpit.hxx>
 #include <svx/xflhtit.hxx>
 #include <svx/svdpage.hxx>
 #include <sfx2/bindings.hxx>
 #include <sfx2/dispatch.hxx>
-#include <sfx2/objface.hxx>
-#include <svx/dlgutil.hxx>
-#include <sfx2/tabdlg.hxx>
 #include <sfx2/sidebar/Panel.hxx>
-#include <algorithm>
 #include <EventMultiplexer.hxx>
+#include <unotools/localedatawrapper.hxx>
 #include <vcl/EnumContext.hxx>
 
-#include <editeng/ulspitem.hxx>
-#include <editeng/lrspitem.hxx>
 #include <editeng/sizeitem.hxx>
-#include <svl/itemset.hxx>
 #include <comphelper/lok.hxx>
 #include <LibreOfficeKit/LibreOfficeKitEnums.h>
+#include <unomodel.hxx>
+#include <sfx2/lokhelper.hxx>
+#include <boost/property_tree/ptree.hpp>
 
 using namespace ::com::sun::star;
 
@@ -135,6 +122,7 @@ SlideBackground::SlideBackground(
     m_nPageRightMargin(0),
     m_nPageTopMargin(0),
     m_nPageBottomMargin(0),
+    meFUnit(GetModuleFieldUnit()),
     maCustomEntry(),
     mpBindings(pBindings)
 {
@@ -157,27 +145,6 @@ SlideBackground::SlideBackground(
     get(mpMasterLabel, "masterlabel");
     get(mpMarginSelectBox, "marginLB");
 
-    ::sd::DrawDocShell* pDocSh = dynamic_cast<::sd::DrawDocShell*>( SfxObjectShell::Current() );
-    SdDrawDocument* pDoc = pDocSh ? pDocSh->GetDoc() : nullptr;
-    if (pDoc)
-    {
-        SdOptions* pOptions = SD_MOD()->GetSdOptions(pDoc->GetDocumentType());
-        if (pOptions)
-        {
-            FieldUnit eMetric = static_cast<FieldUnit>(pOptions->GetMetric());
-            if (IsInch(eMetric))
-            {
-                for (size_t i = 0; i < SAL_N_ELEMENTS(RID_PAGEFORMATPANEL_MARGINS_INCH); ++i)
-                    mpMarginSelectBox->InsertEntry(SdResId(RID_PAGEFORMATPANEL_MARGINS_INCH[i]));
-                }
-            else
-            {
-                for (size_t i = 0; i < SAL_N_ELEMENTS(RID_PAGEFORMATPANEL_MARGINS_CM); ++i)
-                    mpMarginSelectBox->InsertEntry(SdResId(RID_PAGEFORMATPANEL_MARGINS_CM[i]));
-            }
-        }
-    }
-
     maCustomEntry = get<FixedText>("customlabel")->GetText();
 
     addListener();
@@ -203,8 +170,51 @@ bool SlideBackground::IsImpress()
              maContext == maImpressNotesContext );
 }
 
+FieldUnit SlideBackground::GetCurrentUnit(SfxItemState eState, const SfxPoolItem* pState)
+{
+    FieldUnit eUnit;
+
+    if (pState && eState >= SfxItemState::DEFAULT)
+        eUnit = static_cast<FieldUnit>(static_cast<const SfxUInt16Item*>(pState)->GetValue());
+    else
+        eUnit = GetModuleFieldUnit();
+
+    return eUnit;
+}
+
+void SlideBackground::SetMarginsFieldUnit()
+{
+    auto nSelected = mpMarginSelectBox->GetSelectedEntryPos();
+    mpMarginSelectBox->Clear();
+
+    const LocaleDataWrapper& rLocaleData = Application::GetSettings().GetLocaleDataWrapper();
+
+    if (IsInch(meFUnit))
+    {
+        OUString sSuffix = weld::MetricSpinButton::MetricToString(FieldUnit::INCH);
+        for (size_t i = 0; i < SAL_N_ELEMENTS(RID_PAGEFORMATPANEL_MARGINS_INCH); ++i)
+        {
+            OUString sMeasurement = rLocaleData.getNum(RID_PAGEFORMATPANEL_MARGINS_INCH[i].second, 2, true, false) + sSuffix;
+            mpMarginSelectBox->InsertEntry(SdResId(RID_PAGEFORMATPANEL_MARGINS_INCH[i].first).replaceFirst("%1", sMeasurement));
+        }
+    }
+    else
+    {
+        OUString sSuffix = " " + weld::MetricSpinButton::MetricToString(FieldUnit::CM);
+        for (size_t i = 0; i < SAL_N_ELEMENTS(RID_PAGEFORMATPANEL_MARGINS_CM); ++i)
+        {
+            OUString sMeasurement = rLocaleData.getNum(RID_PAGEFORMATPANEL_MARGINS_CM[i].second, 2, true, false) + sSuffix;
+            mpMarginSelectBox->InsertEntry(SdResId(RID_PAGEFORMATPANEL_MARGINS_CM[i].first).replaceFirst("%1", sMeasurement));
+        }
+    }
+
+    mpMarginSelectBox->SelectEntryPos(nSelected);
+}
+
 void SlideBackground::Initialize()
 {
+    SetMarginsFieldUnit();
+
     mpPaperSizeBox->FillPaperSizeEntries( PaperSizeApp::Draw );
     mpPaperSizeBox->SetSelectHdl(LINK(this,SlideBackground,PaperSizeModifyHdl));
     mpPaperOrientation->SetSelectHdl(LINK(this,SlideBackground,PaperSizeModifyHdl));
@@ -246,6 +256,16 @@ void SlideBackground::Initialize()
     UpdateMarginBox();
 }
 
+boost::property_tree::ptree SlideBackground::DumpAsPropertyTree()
+{
+    if (mpPaperSizeBox->GetSelectedEntryCount() == 0)
+    {
+        mpBindings->Update(SID_ATTR_PAGE_SIZE);
+    }
+
+    return Control::DumpAsPropertyTree();
+}
+
 void SlideBackground::HandleContextChange(
     const vcl::EnumContext& rContext)
 {
@@ -298,6 +318,14 @@ void SlideBackground::HandleContextChange(
             mpInsertImage->Show();
         }
 
+        // The Insert Image button in the sidebar issues .uno:SelectBackground,
+        // which when invoked without arguments will open the file-open-dialog
+        // to prompt the user to select a file. This is useless in LOOL.
+        // Hide for now so the user will only be able to use the menu to insert
+        // background image, which prompts the user for file selection in the browser.
+        if (comphelper::LibreOfficeKit::isActive())
+            mpInsertImage->Hide();
+
         // Need to do a relayouting, otherwise the panel size is not updated after show / hide controls
         sfx2::sidebar::Panel* pPanel = dynamic_cast<sfx2::sidebar::Panel*>(GetParent());
         if(pPanel)
@@ -459,11 +487,11 @@ void SlideBackground::SetPanelTitle( const OUString& rTitle )
     if ( !xController.is() )
         return;
 
-    Reference<ui::XSidebarProvider> xSidebarProvider( xController->getSidebar(), uno::UNO_QUERY );
+    Reference<ui::XSidebarProvider> xSidebarProvider = xController->getSidebar();
     if ( !xSidebarProvider.is() )
         return;
 
-    Reference<ui::XDecks> xDecks ( xSidebarProvider->getDecks(), uno::UNO_QUERY);
+    Reference<ui::XDecks> xDecks = xSidebarProvider->getDecks();
     if ( !xDecks.is() )
         return;
 
@@ -471,7 +499,7 @@ void SlideBackground::SetPanelTitle( const OUString& rTitle )
     if ( !xDeck.is() )
         return;
 
-    Reference<ui::XPanels> xPanels ( xDeck->getPanels(), uno::UNO_QUERY);
+    Reference<ui::XPanels> xPanels = xDeck->getPanels();
     if ( !xPanels.is() )
         return;
 
@@ -761,8 +789,7 @@ void SlideBackground::DataChanged (const DataChangedEvent& /*rEvent*/)
 void SlideBackground::NotifyItemUpdate(
     const sal_uInt16 nSID,
     const SfxItemState eState,
-    const SfxPoolItem* pState,
-    const bool)
+    const SfxPoolItem* pState)
 {
     switch(nSID)
     {
@@ -864,7 +891,7 @@ void SlideBackground::NotifyItemUpdate(
             if (pSizeItem)
             {
                 Size aPaperSize = pSizeItem->GetSize();
-                if(mpPaperOrientation->GetSelectedEntryPos() == 0)
+                if (mpPaperOrientation->GetSelectedEntryPos() == 0)
                    Swap(aPaperSize);
 
                 Paper ePaper = SvxPaperInfo::GetSvxPaper(aPaperSize, meUnit);
@@ -940,6 +967,17 @@ void SlideBackground::NotifyItemUpdate(
             }
         }
         break;
+        case SID_ATTR_METRIC:
+        {
+            FieldUnit eFUnit = GetCurrentUnit(eState, pState);
+            if (meFUnit != eFUnit)
+            {
+                meFUnit = eFUnit;
+                SetMarginsFieldUnit();
+                UpdateMarginBox();
+            }
+        }
+        break;
         default:
             break;
     }
@@ -1012,14 +1050,14 @@ IMPL_LINK_NOARG(SlideBackground, PaperSizeModifyHdl, ListBox&, void)
     GetBindings()->GetDispatcher()->ExecuteList(SID_ATTR_PAGE_SIZE, SfxCallMode::RECORD,
                                                 { &aSizeItem, mpPageItem.get(), &aFitObjs });
 
-    // Notify LOK clients of the page size chagne.
+    // Notify LOK clients of the page size change.
     if (comphelper::LibreOfficeKit::isActive())
     {
         SfxViewShell* pViewShell = SfxViewShell::GetFirst();
-        while (pViewShell)
+        if (pViewShell)
         {
-            pViewShell->libreOfficeKitViewCallback(LOK_CALLBACK_DOCUMENT_SIZE_CHANGED, "");
-            pViewShell = SfxViewShell::GetNext(*pViewShell);
+            SdXImpressDocument* pDoc = comphelper::getUnoTunnelImplementation<SdXImpressDocument>(pViewShell->GetCurrentDocument());
+            SfxLokHelper::notifyDocumentSizeChangedAllViews(pDoc);
         }
     }
 }
