@@ -25,13 +25,11 @@
 #include <model/SlsPageDescriptor.hxx>
 #include <model/SlsPageEnumerationProvider.hxx>
 #include <view/SlideSorterView.hxx>
-#include <view/SlsTheme.hxx>
 #include <controller/SlideSorterController.hxx>
 #include <controller/SlsInsertionIndicatorHandler.hxx>
 #include <controller/SlsPageSelector.hxx>
 #include <controller/SlsSelectionFunction.hxx>
 #include <controller/SlsCurrentSlideManager.hxx>
-#include <controller/SlsScrollBarManager.hxx>
 #include <controller/SlsFocusManager.hxx>
 #include <controller/SlsSelectionManager.hxx>
 #include <controller/SlsTransferableData.hxx>
@@ -40,16 +38,9 @@
 #include <cache/SlsPageCache.hxx>
 
 #include <ViewShellBase.hxx>
-#include <View.hxx>
 #include <DrawViewShell.hxx>
 #include <Window.hxx>
 #include <fupoor.hxx>
-#include <fuzoom.hxx>
-#include <fucushow.hxx>
-#include <fusldlg.hxx>
-#include <fuexpand.hxx>
-#include <fusumry.hxx>
-#include <app.hrc>
 #include <strings.hrc>
 #include <sdresid.hxx>
 #include <sdxfer.hxx>
@@ -739,7 +730,17 @@ sal_Int8 Clipboard::ExecuteDrop (
                     mrSlideSorter.GetViewShell()->GetViewShellBase().GetMainViewShell()));
                 mxSelectionObserverContext.reset(new SelectionObserver::Context(mrSlideSorter));
 
-                HandlePageDrop(*pDragTransferable);
+                if (rEvent.mnAction == DND_ACTION_MOVE)
+                {
+                    SdDrawDocument* pDoc = mrSlideSorter.GetModel().GetDocument();
+                    const bool bDoesMakePageObjectsNamesUnique = pDoc->DoesMakePageObjectsNamesUnique();
+                    pDoc->DoMakePageObjectsNamesUnique(false);
+                    HandlePageDrop(*pDragTransferable);
+                    pDoc->DoMakePageObjectsNamesUnique(bDoesMakePageObjectsNamesUnique);
+                }
+                else
+                    HandlePageDrop(*pDragTransferable);
+
                 nResult = rEvent.mnAction;
 
                 // We leave the undo context alive for when moving or
@@ -810,7 +811,7 @@ void Clipboard::Abort()
     }
 }
 
-sal_uInt16 Clipboard::DetermineInsertPosition (const SdTransferable& )
+sal_uInt16 Clipboard::DetermineInsertPosition ()
 {
     // Tell the model to move the dragged pages behind the one with the
     // index nInsertionIndex which first has to be transformed into an index
