@@ -22,15 +22,16 @@
 #include <ViewShellBase.hxx>
 #include <Window.hxx>
 #include <DrawDocShell.hxx>
-#include <FormShellManager.hxx>
 
 #include <sal/log.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <svx/svxids.hrc>
 #include <svx/fmshell.hxx>
+#include <vcl/vclevent.hxx>
 
 #include <iterator>
+#include <list>
 #include <unordered_map>
 
 namespace sd {
@@ -204,7 +205,7 @@ private:
     void DumpSfxShellStack();
 #endif
 
-    /** To be called before a shell is taken fom the SFX shell stack.  This
+    /** To be called before a shell is taken from the SFX shell stack.  This
         method deactivates an active text editing to avoid problems with
         undo managers.
         Afterwards the Deactivate() of the shell is called.
@@ -886,7 +887,7 @@ void ViewShellManager::Implementation::CreateShells()
 void ViewShellManager::Implementation::CreateTargetStack (ShellStack& rStack) const
 {
     // Create a local stack of the shells that are to push on the shell
-    // stack.  We can thus safely create the required shells wile still
+    // stack.  We can thus safely create the required shells while still
     // having a valid shell stack.
     for (ActiveShellList::const_reverse_iterator iViewShell (maActiveViewShells.rbegin());
          iViewShell != maActiveViewShells.rend();
