@@ -38,7 +38,6 @@
 
 #include <rtl/strbuf.hxx>
 #include <rtl/ustrbuf.hxx>
-#include <rtl/alloc.h>
 #include <sal/log.hxx>
 
 // disable warnings again because someone along the line has enabled them
@@ -573,7 +572,7 @@ std::unique_ptr<PDFEntry> PDFReader::read( const char* pBuffer, unsigned int nLe
         OString aTmp;
         unsigned int nElem = aGrammar.m_aObjectStack.size();
         for( unsigned int i = 0; i < nElem; i++ )
-            aTmp += "   " + OString(typeid( *(aGrammar.m_aObjectStack[i]) ).name());
+            aTmp += OStringLiteral("   ") + typeid( *(aGrammar.m_aObjectStack[i]) ).name();
 
         SAL_WARN("sdext.pdfimport.pdfparse", "parse error: " << rError.descriptor << " at buffer pos " << rError.where - pBuffer << ", object stack: " << aTmp);
 #else
