@@ -67,6 +67,7 @@
 #include <rtl/ref.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <tools/datetime.hxx>
+#include <tools/diagnose_ex.h>
 #include <osl/mutex.hxx>
 #include <comphelper/fileformat.h>
 #include <cppuhelper/basemutex.hxx>
@@ -325,7 +326,7 @@ public:
 // XServiceInfo
     virtual OUString SAL_CALL getImplementationName(  ) override
     {
-        return OUString("CompatWriterDocPropsImpl");
+        return "CompatWriterDocPropsImpl";
     }
 
     virtual sal_Bool SAL_CALL supportsService( const OUString& ServiceName ) override
@@ -508,7 +509,7 @@ dateTimeToText(css::util::DateTime const& i_rdt,
                sal_Int16 const*const pTimeZone = nullptr) throw ()
 {
     if (isValidDateTime(i_rdt)) {
-        OUStringBuffer buf;
+        OUStringBuffer buf(32);
         ::sax::Converter::convertDateTime(buf, i_rdt, pTimeZone, true);
         return buf.makeStringAndClear();
     } else {
@@ -570,18 +571,18 @@ SfxDocumentMetaData::getURLProperties(
     css::uno::Reference< css::beans::XPropertyBag> xPropArg = css::beans::PropertyBag::createDefault( m_xContext );
     try {
         css::uno::Any baseUri;
-        for (sal_Int32 i = 0; i < i_rMedium.getLength(); ++i) {
-            if (i_rMedium[i].Name == "DocumentBaseURL") {
-                baseUri = i_rMedium[i].Value;
-            } else if (i_rMedium[i].Name == "URL") {
+        for (const auto& rProp : i_rMedium) {
+            if (rProp.Name == "DocumentBaseURL") {
+                baseUri = rProp.Value;
+            } else if (rProp.Name == "URL") {
                 if (!baseUri.hasValue()) {
-                    baseUri = i_rMedium[i].Value;
+                    baseUri = rProp.Value;
                 }
-            } else if (i_rMedium[i].Name == "HierarchicalDocumentName") {
+            } else if (rProp.Name == "HierarchicalDocumentName") {
                 xPropArg->addProperty(
                     "StreamRelPath",
                     css::beans::PropertyAttribute::MAYBEVOID,
-                    i_rMedium[i].Value);
+                    rProp.Value);
             }
         }
         if (baseUri.hasValue()) {
@@ -1263,7 +1264,7 @@ SfxDocumentMetaData::SfxDocumentMetaData(
 OUString SAL_CALL
 SfxDocumentMetaData::getImplementationName()
 {
-    return OUString("SfxDocumentMetaData");
+    return "SfxDocumentMetaData";
 }
 
 sal_Bool SAL_CALL
@@ -1620,12 +1621,12 @@ SfxDocumentMetaData::setDocumentStatistics(
         osl::MutexGuard g(m_aMutex);
         checkInit();
         std::vector<std::pair<const char *, OUString> > attributes;
-        for (sal_Int32 i = 0; i < the_value.getLength(); ++i) {
-            const OUString name = the_value[i].Name;
+        for (const auto& rValue : the_value) {
+            const OUString name = rValue.Name;
             // inefficiently search for matching attribute
             for (size_t j = 0; s_stdStats[j] != nullptr; ++j) {
                 if (name.equalsAscii(s_stdStats[j])) {
-                    const css::uno::Any any = the_value[i].Value;
+                    const css::uno::Any any = rValue.Value;
                     sal_Int32 val = 0;
                     if (any >>= val) {
                         attributes.emplace_back(s_stdStatAttrs[j],
@@ -2046,9 +2047,9 @@ void SAL_CALL SfxDocumentMetaData::setModified( sal_Bool bModified )
                 event);
         } catch (const css::uno::RuntimeException &) {
             throw;
-        } catch (const css::uno::Exception & e) {
+        } catch (const css::uno::Exception &) {
             // ignore
-            SAL_WARN("sfx.doc", "setModified: " << e);
+            TOOLS_WARN_EXCEPTION("sfx.doc", "setModified");
         }
     } else {
         if (xMB.is()) {
