@@ -76,7 +76,6 @@ sub get_msiassembly_filemanifest
     return $filemanifest;
 }
 
-
 ##############################################################
 # Returning the file application
 ##############################################################
@@ -105,35 +104,6 @@ sub get_msiassembly_attributes
     return $fileattributes;
 }
 
-##############################################################
-# Returning the file object for the msiassembly table.
-##############################################################
-
-sub get_msiassembly_file
-{
-    my ( $filesref, $filename ) = @_;
-
-    my $foundfile = 0;
-    my $onefile;
-
-    for ( my $i = 0; $i <= $#{$filesref}; $i++ )
-    {
-        $onefile = ${$filesref}[$i];
-        my $name = $onefile->{'Name'};
-
-        if ( $name eq $filename )
-        {
-            $foundfile = 1;
-            last;
-        }
-    }
-
-    # It does not need to exist. For example products that do not contain the libraries.
-    if (! $foundfile ) { $onefile  = ""; }
-
-    return $onefile;
-}
-
 ####################################################################################
 # Creating the file MsiAssembly.idt dynamically
 # Content:
