@@ -73,26 +73,16 @@ void AccessibleCell::Init()
     const vcl::Window* pWindow = maShapeTreeInfo.GetWindow ();
     if( (pView != nullptr) && (pWindow != nullptr) && mxCell.is())
     {
-        OutlinerParaObject* pOutlinerParaObject = mxCell->GetEditOutlinerParaObject().release(); // Get the OutlinerParaObject if text edit is active
-
-        bool bOwnParaObject = pOutlinerParaObject != nullptr;
-
-        if( !pOutlinerParaObject )
-            pOutlinerParaObject = mxCell->GetOutlinerParaObject();
-
         // create AccessibleTextHelper to handle this shape's text
-        if( pOutlinerParaObject )
+        if( mxCell->CanCreateEditOutlinerParaObject() || mxCell->GetOutlinerParaObject() != nullptr )
         {
             // non-empty text -> use full-fledged edit source right away
 
             mpText.reset( new AccessibleTextHelper( std::make_unique<SvxTextEditSource>(mxCell->GetObject(), mxCell.get(), *pView, *pWindow) ) );
-            if( mxCell.is() && mxCell.get()->IsActiveCell() )
+            if( mxCell.is() && mxCell->IsActiveCell() )
                 mpText->SetFocus();
             mpText->SetEventSource(this);
         }
-
-        if( bOwnParaObject)
-            delete pOutlinerParaObject;
     }
 }
 
@@ -230,18 +220,14 @@ Reference<XAccessibleStateSet> SAL_CALL AccessibleCell::getAccessibleStateSet()
                 {
                     css::uno::Reference<XAccessibleStateSet> rState =
                         xTempAccContext->getAccessibleStateSet();
-                    if( rState.is() )           {
+                    if( rState.is() )
+                    {
                         css::uno::Sequence<short> aStates = rState->getStates();
-                        int count = aStates.getLength();
-                        for( int iIndex = 0;iIndex < count;iIndex++ )
+                        if (std::find(aStates.begin(), aStates.end(), AccessibleStateType::EDITABLE) != aStates.end())
                         {
-                            if( aStates[iIndex] == AccessibleStateType::EDITABLE )
-                            {
-                                pStateSet->AddState (AccessibleStateType::EDITABLE);
-                                pStateSet->AddState (AccessibleStateType::RESIZABLE);
-                                pStateSet->AddState (AccessibleStateType::MOVEABLE);
-                                break;
-                            }
+                            pStateSet->AddState (AccessibleStateType::EDITABLE);
+                            pStateSet->AddState (AccessibleStateType::RESIZABLE);
+                            pStateSet->AddState (AccessibleStateType::MOVEABLE);
                         }
                     }
                 }
@@ -470,7 +456,7 @@ void SAL_CALL AccessibleCell::removeAccessibleEventListener( const Reference<XAc
 
 OUString SAL_CALL AccessibleCell::getImplementationName()
 {
-    return OUString("AccessibleCell");
+    return "AccessibleCell";
 }
 
 
