@@ -277,8 +277,7 @@ ErrCode SwXMLTextBlocks::GetBlockText( const OUString& rShort, OUString& rText )
         bool bTextOnly = true;
 
         xRoot = xBlkRoot->openStorageElement( aFolderName, embed::ElementModes::READ );
-        uno::Reference < container::XNameAccess > xAccess( xRoot, uno::UNO_QUERY );
-        if ( !xAccess->hasByName( aStreamName ) || !xRoot->isStreamElement( aStreamName ) )
+        if ( !xRoot->hasByName( aStreamName ) || !xRoot->isStreamElement( aStreamName ) )
         {
             bTextOnly = false;
             aStreamName = "content.xml";
@@ -360,13 +359,9 @@ ErrCode SwXMLTextBlocks::PutBlockText( const OUString& rShort,
     uno::Reference < beans::XPropertySet > xSet( xDocStream, uno::UNO_QUERY );
     xSet->setPropertyValue("MediaType", Any(OUString( "text/xml" )) );
     uno::Reference < io::XOutputStream > xOut = xDocStream->getOutputStream();
-    uno::Reference<io::XActiveDataSource> xSrc(xWriter, uno::UNO_QUERY);
-    xSrc->setOutputStream(xOut);
+    xWriter->setOutputStream(xOut);
 
-    uno::Reference<xml::sax::XDocumentHandler> xHandler(xWriter,
-        uno::UNO_QUERY);
-
-    rtl::Reference<SwXMLTextBlockExport> xExp( new SwXMLTextBlockExport( xContext, *this, GetXMLToken ( XML_UNFORMATTED_TEXT ), xHandler) );
+    rtl::Reference<SwXMLTextBlockExport> xExp( new SwXMLTextBlockExport( xContext, *this, GetXMLToken ( XML_UNFORMATTED_TEXT ), xWriter) );
 
     xExp->exportDoc( rText );
 
@@ -408,8 +403,7 @@ void SwXMLTextBlocks::ReadInfo()
     try
     {
     const OUString sDocName( XMLN_BLOCKLIST );
-    uno::Reference < container::XNameAccess > xAccess( xBlkRoot, uno::UNO_QUERY );
-    if ( xAccess.is() && xAccess->hasByName( sDocName ) && xBlkRoot->isStreamElement( sDocName ) )
+    if ( xBlkRoot.is() && xBlkRoot->hasByName( sDocName ) && xBlkRoot->isStreamElement( sDocName ) )
     {
         uno::Reference< uno::XComponentContext > xContext =
                 comphelper::getProcessComponentContext();
@@ -479,12 +473,9 @@ void SwXMLTextBlocks::WriteInfo()
         uno::Reference < beans::XPropertySet > xSet( xDocStream, uno::UNO_QUERY );
         xSet->setPropertyValue("MediaType", Any(OUString( "text/xml" )) );
         uno::Reference < io::XOutputStream > xOut = xDocStream->getOutputStream();
-        uno::Reference<io::XActiveDataSource> xSrc(xWriter, uno::UNO_QUERY);
-        xSrc->setOutputStream(xOut);
+        xWriter->setOutputStream(xOut);
 
-        uno::Reference<xml::sax::XDocumentHandler> xHandler(xWriter, uno::UNO_QUERY);
-
-        rtl::Reference<SwXMLBlockListExport> xExp(new SwXMLBlockListExport( xContext, *this, XMLN_BLOCKLIST, xHandler) );
+        rtl::Reference<SwXMLBlockListExport> xExp(new SwXMLBlockListExport( xContext, *this, XMLN_BLOCKLIST, xWriter) );
 
         xExp->exportDoc( XML_BLOCK_LIST );
 
@@ -517,8 +508,8 @@ ErrCode SwXMLTextBlocks::SetMacroTable(
         comphelper::getProcessComponentContext();
 
     // Get model
-    uno::Reference< lang::XComponent > xModelComp(
-        m_xDoc->GetDocShell()->GetModel(), UNO_QUERY );
+    uno::Reference< lang::XComponent > xModelComp =
+        m_xDoc->GetDocShell()->GetModel();
     OSL_ENSURE( xModelComp.is(), "XMLWriter::Write: got no model" );
     if( !xModelComp.is() )
         return ERR_SWG_WRITE_ERROR;
@@ -547,8 +538,6 @@ ErrCode SwXMLTextBlocks::SetMacroTable(
 
             // connect XML writer to output stream
             xSaxWriter->setOutputStream( xOutputStream );
-            uno::Reference<xml::sax::XDocumentHandler> xDocHandler(
-                xSaxWriter, UNO_QUERY);
 
             // construct events object
             uno::Reference<XNameAccess> xEvents =
@@ -556,7 +545,7 @@ ErrCode SwXMLTextBlocks::SetMacroTable(
 
             // prepare arguments (prepend doc handler to given arguments)
             Sequence<Any> aParams(2);
-            aParams[0] <<= xDocHandler;
+            aParams[0] <<= xSaxWriter;
             aParams[1] <<= xEvents;
 
             // get filter component
