@@ -849,6 +849,10 @@ void SwUndoSaveContent::DelContentIndex( const SwPosition& rMark,
 
     SwDoc* pDoc = rMark.nNode.GetNode().GetDoc();
 
+    // if it's not in the doc array, probably missing some invalidation somewhere
+    assert(&rPoint.nNode.GetNodes() == &pDoc->GetNodes());
+    assert(&rMark.nNode.GetNodes() == &pDoc->GetNodes());
+
     ::sw::UndoGuard const undoGuard(pDoc->GetIDocumentUndoRedo());
 
     // 1. Footnotes
@@ -1097,12 +1101,14 @@ void SwUndoSaveContent::DelContentIndex( const SwPosition& rMark,
                     if( pBkmk->IsExpanded() &&
                         *pStt <= pBkmk->GetOtherMarkPos() && pBkmk->GetOtherMarkPos() <= *pEnd )
                     {
-                        if ( bSavePos || bSaveOtherPos
+                        assert(!bSaveOtherPos);
+                        if (   bSavePos
                             || (*pStt < pBkmk->GetOtherMarkPos() && pBkmk->GetOtherMarkPos() < *pEnd)
-                            || type == IDocumentMarkAccess::MarkType::TEXT_FIELDMARK
-                            || type == IDocumentMarkAccess::MarkType::CHECKBOX_FIELDMARK
-                            || type == IDocumentMarkAccess::MarkType::DROPDOWN_FIELDMARK
-                            || type == IDocumentMarkAccess::MarkType::DATE_FIELDMARK)
+                            || (bMaybe
+                                && (   type == IDocumentMarkAccess::MarkType::TEXT_FIELDMARK
+                                    || type == IDocumentMarkAccess::MarkType::CHECKBOX_FIELDMARK
+                                    || type == IDocumentMarkAccess::MarkType::DROPDOWN_FIELDMARK
+                                    || type == IDocumentMarkAccess::MarkType::DATE_FIELDMARK)))
                         {
                             if( bMaybe )
                                 bSavePos = true;
