@@ -24,9 +24,10 @@
 
 #include <com/sun/star/scanner/XScannerManager2.hpp>
 #include <com/sun/star/datatransfer/clipboard/XClipboard.hpp>
+#include <comphelper/propertysequence.hxx>
+#include <comphelper/servicehelper.hxx>
 #include <vcl/weld.hxx>
 #include <vcl/svapp.hxx>
-#include <vcl/wrkwin.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/bindings.hxx>
 #include <sfx2/docfile.hxx>
@@ -65,15 +66,9 @@ SwView_Impl::SwView_Impl(SwView* pShell)
 
 SwView_Impl::~SwView_Impl()
 {
-    Reference<XUnoTunnel> xDispTunnel(xDisProvInterceptor, UNO_QUERY);
-    SwXDispatchProviderInterceptor* pInterceptor = nullptr;
-    if(xDispTunnel.is() &&
-        nullptr != (pInterceptor = reinterpret_cast< SwXDispatchProviderInterceptor * >(
-                    sal::static_int_cast< sal_IntPtr >(
-                    xDispTunnel->getSomething(SwXDispatchProviderInterceptor::getUnoTunnelId())))))
-    {
+    auto pInterceptor = comphelper::getUnoTunnelImplementation<SwXDispatchProviderInterceptor>(xDisProvInterceptor);
+    if(pInterceptor)
         pInterceptor->Invalidate();
-    }
     view::XSelectionSupplier* pTextView = mxXTextView.get();
     static_cast<SwXTextView*>(pTextView)->Invalidate();
     mxXTextView.clear();
@@ -128,6 +123,19 @@ void SwView_Impl::ExecuteScan( SfxRequest& rReq )
                     {
                         Reference< XEventListener > xLstner = &rListener;
                         ScannerContext aContext( aContexts.getConstArray()[ 0 ] );
+
+                        Reference<lang::XInitialization> xInit(xScanMgr, UNO_QUERY);
+                        if (xInit.is())
+                        {
+                            //  initialize dialog
+                            weld::Window* pWindow = rReq.GetFrameWeld();
+                            uno::Sequence<uno::Any> aSeq(comphelper::InitAnyPropertySequence(
+                            {
+                                {"ParentWindow", pWindow ? uno::Any(pWindow->GetXWindow()) : uno::Any(Reference<awt::XWindow>())}
+                            }));
+                            xInit->initialize( aSeq );
+                        }
+
                         bDone = xScanMgr->configureScannerAndScan( aContext, xLstner );
                     }
                 }
@@ -170,7 +178,7 @@ void SwView_Impl::ExecuteScan( SfxRequest& rReq )
 
             if( !bDone )
             {
-                std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(nullptr,
+                std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(rReq.GetFrameWeld(),
                                                           VclMessageType::Info, VclButtonsType::Ok,
                                                           SwResId(STR_SCAN_NOSOURCE)));
                 xBox->run();
@@ -209,16 +217,9 @@ void SwView_Impl::Invalidate()
     GetUNOObject_Impl()->Invalidate();
     for (const auto& xTransferable: mxTransferables)
     {
-        Reference< XUnoTunnel > xTunnel(xTransferable.get(), UNO_QUERY);
-        if(xTunnel.is())
-
-        {
-            SwTransferable* pTransferable = reinterpret_cast< SwTransferable * >(
-                    sal::static_int_cast< sal_IntPtr >(
-                    xTunnel->getSomething(SwTransferable::getUnoTunnelId())));
-            if(pTransferable)
-                pTransferable->Invalidate();
-        }
+        auto pTransferable = comphelper::getUnoTunnelImplementation<SwTransferable>(xTransferable.get());
+        if(pTransferable)
+            pTransferable->Invalidate();
     }
 }
 
