@@ -22,13 +22,9 @@
 #include <memory>
 #include <com/sun/star/awt/WindowEvent.hpp>
 #include <com/sun/star/awt/KeyEvent.hpp>
-#include <com/sun/star/awt/KeyModifier.hpp>
 #include <com/sun/star/awt/MouseEvent.hpp>
-#include <com/sun/star/awt/MouseButton.hpp>
 #include <com/sun/star/awt/MouseWheelBehavior.hpp>
-#include <com/sun/star/awt/XTopWindow.hpp>
 #include <com/sun/star/awt/Style.hpp>
-#include <com/sun/star/accessibility/AccessibleRole.hpp>
 #include <com/sun/star/awt/DockingEvent.hpp>
 #include <com/sun/star/awt/EndDockingEvent.hpp>
 #include <com/sun/star/awt/EndPopupModeEvent.hpp>
@@ -39,13 +35,9 @@
 #include <toolkit/awt/vclxwindow.hxx>
 #include <toolkit/awt/vclxpointer.hxx>
 #include <toolkit/awt/vclxwindows.hxx>
-#include <toolkit/helper/macros.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <toolkit/helper/convert.hxx>
 #include <toolkit/helper/property.hxx>
-#include <cppuhelper/typeprovider.hxx>
-#include <rtl/uuid.h>
-#include <rtl/ustrbuf.hxx>
 #include <sal/log.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/window.hxx>
@@ -56,10 +48,9 @@
 #include <vcl/dockwin.hxx>
 #include <vcl/pdfextoutdevdata.hxx>
 #include <vcl/tabpage.hxx>
-#include <vcl/button.hxx>
+#include <vcl/ctrl.hxx>
 #include <vcl/settings.hxx>
 #include <vcl/commandevent.hxx>
-#include <comphelper/asyncnotification.hxx>
 #include <comphelper/flagguard.hxx>
 #include <comphelper/interfacecontainer2.hxx>
 #include <comphelper/profilezone.hxx>
@@ -156,11 +147,11 @@ public:
     /** synchronously mbEnableVisible
     */
     void    setEnableVisible( bool bEnableVisible ) { mbEnableVisible = bEnableVisible; }
-    bool    isEnableVisible() { return mbEnableVisible; }
+    bool    isEnableVisible() const { return mbEnableVisible; }
     /** synchronously mbDirectVisible;
     */
     void    setDirectVisible( bool bDirectVisible ) { mbDirectVisible = bDirectVisible; }
-    bool    isDirectVisible() { return mbDirectVisible; }
+    bool    isDirectVisible() const { return mbDirectVisible; }
 
     /** impl-version of VCLXWindow::ImplExecuteAsyncWithoutSolarLock
     */
@@ -905,27 +896,7 @@ Size VCLXWindow::ImplCalcWindowSize( const Size& rOutSz ) const
 
 
 // css::lang::XUnoTunnel
-sal_Int64 VCLXWindow::getSomething( const css::uno::Sequence< sal_Int8 >& rIdentifier )
-{
-    if( ( rIdentifier.getLength() == 16 ) && ( 0 == memcmp( VCLXWindow::GetUnoTunnelId().getConstArray(), rIdentifier.getConstArray(), 16 ) ) )
-    {
-        return sal::static_int_cast< sal_Int64 >(reinterpret_cast< sal_IntPtr >(this));
-    }
-    return VCLXDevice::getSomething( rIdentifier );
-}
-namespace
-{
-    class theVCLXWindowUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theVCLXWindowUnoTunnelId> {};
-}
-const css::uno::Sequence< sal_Int8 >& VCLXWindow::GetUnoTunnelId() throw()
-{
-    return theVCLXWindowUnoTunnelId::get().getSeq();
-}
-VCLXWindow* VCLXWindow::GetImplementation( const css::uno::Reference< css::uno::XInterface >& rxIFace )
-{
-    css::uno::Reference< css::lang::XUnoTunnel > xUT( rxIFace, css::uno::UNO_QUERY );
-    return xUT.is() ? reinterpret_cast<VCLXWindow*>(sal::static_int_cast<sal_IntPtr>(xUT->getSomething( VCLXWindow::GetUnoTunnelId() ))) : nullptr;
-}
+UNO3_GETIMPLEMENTATION2_IMPL(VCLXWindow, VCLXDevice);
 
 
 // css::lang::Component
@@ -1144,7 +1115,7 @@ void VCLXWindow::setPointer( const css::uno::Reference< css::awt::XPointer >& rx
 {
     SolarMutexGuard aGuard;
 
-    VCLXPointer* pPointer = VCLXPointer::GetImplementation( rxPointer );
+    VCLXPointer* pPointer = comphelper::getUnoTunnelImplementation<VCLXPointer>( rxPointer );
     if ( pPointer && GetWindow() )
         GetWindow()->SetPointer( pPointer->GetPointer() );
 }
@@ -2013,7 +1984,7 @@ css::uno::Any VCLXWindow::getProperty( const OUString& PropertyName )
                 aProp <<= GetWindow()->GetControlBackground();
             break;
             case BASEPROPERTY_DISPLAYBACKGROUNDCOLOR:
-                aProp <<= GetWindow()->GetDisplayBackground().GetColor();
+                aProp <<= GetWindow()->GetBackgroundColor();
             break;
             case BASEPROPERTY_FONTRELIEF:
                 aProp <<= static_cast<sal_Int16>(GetWindow()->GetControlFont().GetRelief());
@@ -2263,7 +2234,7 @@ void VCLXWindow::draw( sal_Int32 nX, sal_Int32 nY )
             // #i40647# don't draw here if this is a recursive call
             // sometimes this is called recursively, because the Update call on the parent
             // (strangely) triggers another paint. Prevent a stack overflow here
-            // Yes, this is only fixing symptoms for the moment ....
+            // Yes, this is only fixing symptoms for the moment...
             // #i40647# / 2005-01-18 / frank.schoenheit@sun.com
             if ( !mpImpl->getDrawingOntoParent_ref() )
             {
