@@ -83,12 +83,11 @@ SvtOptionsDlgOptions_Impl::SvtOptionsDlgOptions_Impl()
     m_aOptionNodeList( OptionNodeList() )
 {
     OUString sRootNode( ROOT_NODE );
-    Sequence< OUString > aNodeSeq = GetNodeNames( sRootNode );
+    const Sequence< OUString > aNodeSeq = GetNodeNames( sRootNode );
     OUString sNode( sRootNode + g_sPathDelimiter );
-    sal_uInt32 nCount = aNodeSeq.getLength();
-    for ( sal_uInt32 n = 0; n < nCount; n++ )
+    for ( const auto& rNode : aNodeSeq )
     {
-        OUString sSubNode( sNode + aNodeSeq[n] );
+        OUString sSubNode( sNode + rNode );
         ReadNode( sSubNode, NT_Group );
     }
 }
@@ -144,14 +143,11 @@ void SvtOptionsDlgOptions_Impl::ReadNode( const OUString& _rNode, NodeType _eTyp
     if ( _eType != NT_Option )
     {
         OUString sNodes( sNode + sSet );
-        Sequence< OUString > aNodes = GetNodeNames( sNodes );
-        if ( aNodes.hasElements() )
+        const Sequence< OUString > aNodes = GetNodeNames( sNodes );
+        for ( const auto& rNode : aNodes )
         {
-            for ( sal_uInt32 n = 0; n < static_cast<sal_uInt32>(aNodes.getLength()); ++n )
-            {
-                OUString sSubNodeName( sNodes + g_sPathDelimiter + aNodes[n] );
-                ReadNode( sSubNodeName, _eType == NT_Group ? NT_Page : NT_Option );
-            }
+            OUString sSubNodeName( sNodes + g_sPathDelimiter + rNode );
+            ReadNode( sSubNodeName, _eType == NT_Group ? NT_Page : NT_Option );
         }
     }
 }
