@@ -24,6 +24,7 @@
 #include <com/sun/star/frame/XFrame.hpp>
 #include <com/sun/star/frame/XController.hpp>
 #include <com/sun/star/frame/XModel2.hpp>
+#include <com/sun/star/script/BasicErrorException.hpp>
 #include <com/sun/star/script/XDefaultProperty.hpp>
 #include <com/sun/star/script/Converter.hpp>
 #include <com/sun/star/uno/XComponentContext.hpp>
@@ -41,6 +42,7 @@
 
 #include <comphelper/automationinvokedzone.hxx>
 #include <comphelper/processfactory.hxx>
+#include <comphelper/sequence.hxx>
 #include <i18nlangtag/languagetag.hxx>
 
 #include <sfx2/objsh.hxx>
@@ -164,11 +166,7 @@ dispatchRequests (const uno::Reference< frame::XModel>& xModel, const OUString &
     if ( nProps )
     {
         dispatchProps.realloc( nProps + 1 );
-        // need to acquire pDest after realloc
-        beans::PropertyValue* pDest = dispatchProps.getArray();
-        const beans::PropertyValue* pSrc = sProps.getConstArray();
-        for ( sal_Int32 index=0; index<nProps; ++index, ++pSrc, ++pDest )
-            *pDest = *pSrc;
+        std::copy(sProps.begin(), sProps.end(), dispatchProps.begin());
     }
 
     if ( xDispatcher.is() )
@@ -517,21 +515,17 @@ ContainerUtilities::getUniqueName( const uno::Sequence< OUString >&  _slist, con
 OUString
 ContainerUtilities::getUniqueName( const uno::Sequence< OUString >& _slist, const OUString& _sElementName, const OUString& _sSuffixSeparator, sal_Int32 _nStartSuffix)
 {
-    sal_Int32 a = _nStartSuffix;
-    OUString scompname = _sElementName;
-    sal_Int32 nLen = _slist.getLength();
-    if ( nLen == 0 )
+    if ( !_slist.hasElements() )
         return _sElementName;
 
+    OUString scompname = _sElementName;
+    sal_Int32 a = _nStartSuffix;
+
     for (;;)
     {
-        for (sal_Int32 i = 0; i < nLen; i++)
-        {
-            if (FieldInList(_slist, scompname) == -1)
-            {
-                return scompname;
-            }
-        }
+        if (FieldInList(_slist, scompname) == -1)
+            return scompname;
+
         scompname = _sElementName + _sSuffixSeparator + OUString::number( a++ );
     }
 }
@@ -539,20 +533,9 @@ ContainerUtilities::getUniqueName( const uno::Sequence< OUString >& _slist, cons
 sal_Int32
 ContainerUtilities::FieldInList( const uno::Sequence< OUString >& SearchList, const OUString& SearchString )
 {
-    sal_Int32 FieldLen = SearchList.getLength();
-    sal_Int32 retvalue = -1;
-    for (sal_Int32 i = 0; i < FieldLen; i++)
-    {
-        // I wonder why comparing lexicographically is done
-        // when it's a match, is it interesting?
-        if ( SearchList[i] == SearchString )
-        {
-            retvalue = i;
-            break;
-        }
-    }
-    return retvalue;
-
+    // I wonder why comparing lexicographically is done
+    // when it's a match, is it interesting?
+    return comphelper::findValue(SearchList, SearchString);
 }
 
 static bool NeedEsc(sal_Unicode cCode)
@@ -757,25 +740,21 @@ void setDefaultPropByIntrospection( const uno::Any& aObj, const uno::Any& aValue
 
 uno::Any getPropertyValue( const uno::Sequence< beans::PropertyValue >& aProp, const OUString& aName )
 {
-    for ( sal_Int32 i = 0; i < aProp.getLength(); i++ )
-    {
-        if ( aProp[i].Name == aName )
-        {
-            return aProp[i].Value;
-        }
-    }
+    auto pProp = std::find_if(aProp.begin(), aProp.end(),
+        [&aName](const beans::PropertyValue& rProp) { return rProp.Name == aName; });
+    if (pProp != aProp.end())
+        return pProp->Value;
     return uno::Any();
 }
 
 bool setPropertyValue( uno::Sequence< beans::PropertyValue >& aProp, const OUString& aName, const uno::Any& aValue )
 {
-    for ( sal_Int32 i = 0; i < aProp.getLength(); i++ )
+    auto pProp = std::find_if(aProp.begin(), aProp.end(),
+        [&aName](const beans::PropertyValue& rProp) { return rProp.Name == aName; });
+    if (pProp != aProp.end())
     {
-        if ( aProp[i].Name == aName )
-        {
-            aProp[i].Value = aValue;
-            return true;
-        }
+        pProp->Value = aValue;
+        return true;
     }
     return false;
 }
@@ -1081,7 +1060,7 @@ void Millimeter::setInPoints(double points)
     m_nMillimeter = points * factor / 100.0;
 }
 
-double Millimeter::getInHundredthsOfOneMillimeter()
+double Millimeter::getInHundredthsOfOneMillimeter() const
 {
     return m_nMillimeter * 100;
 }
