@@ -28,7 +28,6 @@
 #include <vcl/bitmap.hxx>
 #include <vcl/checksum.hxx>
 #include <vcl/outdev.hxx>
-#include <vcl/salbtype.hxx>
 #include <svdata.hxx>
 #include <salgdi.hxx>
 #include <vcleventlisteners.hxx>
@@ -57,10 +56,6 @@ bool determineTextureFormat(sal_uInt16 nBits, GLenum& nFormat, GLenum& nType)
         nFormat = GL_LUMINANCE;
         nType = GL_UNSIGNED_BYTE;
         return true;
-    case 16:
-        nFormat = GL_RGB;
-        nType = GL_UNSIGNED_SHORT_5_6_5;
-        return true;
     case 24:
         nFormat = GL_RGB;
         nType = GL_UNSIGNED_BYTE;
@@ -78,7 +73,7 @@ bool determineTextureFormat(sal_uInt16 nBits, GLenum& nFormat, GLenum& nType)
 
 bool isValidBitCount( sal_uInt16 nBitCount )
 {
-    return (nBitCount == 1) || (nBitCount == 4) || (nBitCount == 8) || (nBitCount == 16) || (nBitCount == 24) || (nBitCount == 32);
+    return (nBitCount == 1) || (nBitCount == 4) || (nBitCount == 8) || (nBitCount == 24) || (nBitCount == 32);
 }
 
 sal_uInt32 lclBytesPerRow(sal_uInt16 nBits, int nWidth)
@@ -88,7 +83,6 @@ sal_uInt32 lclBytesPerRow(sal_uInt16 nBits, int nWidth)
     case 1:  return (nWidth + 7) >> 3;
     case 4:  return (nWidth + 1) >> 1;
     case 8:  return  nWidth;
-    case 16: return  nWidth * 2;
     case 24: return  nWidth * 3;
     case 32: return  nWidth * 4;
     default:
@@ -494,7 +488,7 @@ GLuint OpenGLSalBitmap::CreateTexture()
 
     if (mpUserBuffer != nullptr)
     {
-        if( mnBits == 16 || mnBits == 24 || mnBits == 32 )
+        if( mnBits == 24 || mnBits == 32 )
         {
             // no conversion needed for truecolor
             pData = mpUserBuffer.get();
@@ -580,7 +574,7 @@ bool OpenGLSalBitmap::ReadTexture()
     xContext->state().scissor().disable();
     xContext->state().stencil().disable();
 
-    if ((mnBits == 8 && maPalette.IsGreyPalette()) || mnBits == 16 || mnBits == 24 || mnBits == 32)
+    if ((mnBits == 8 && maPalette.IsGreyPalette()) || mnBits == 24 || mnBits == 32)
     {
         determineTextureFormat(mnBits, nFormat, nType);
 
@@ -684,7 +678,7 @@ bool OpenGLSalBitmap::calcChecksumGL(OpenGLTexture& rInputTexture, BitmapChecksu
     int nNewWidth = ceil( nWidth / 4.0 );
     int nNewHeight = ceil( nHeight / 4.0 );
 
-    OpenGLTexture aFirstPassTexture = OpenGLTexture(nNewWidth, nNewHeight);
+    OpenGLTexture aFirstPassTexture(nNewWidth, nNewHeight);
     OpenGLFramebuffer* pFramebuffer = xContext->AcquireFramebuffer(aFirstPassTexture);
 
     pProgram->SetUniform1f( "xstep", 1.0 / mnWidth );
@@ -711,7 +705,7 @@ bool OpenGLSalBitmap::calcChecksumGL(OpenGLTexture& rInputTexture, BitmapChecksu
     nNewWidth = ceil( nWidth / 4.0 );
     nNewHeight = ceil( nHeight / 4.0 );
 
-    OpenGLTexture aSecondPassTexture = OpenGLTexture(nNewWidth, nNewHeight);
+    OpenGLTexture aSecondPassTexture(nNewWidth, nNewHeight);
     pFramebuffer = xContext->AcquireFramebuffer(aSecondPassTexture);
 
     pProgram->SetUniform1f( "xstep", 1.0 / mnWidth );
@@ -804,18 +798,6 @@ BitmapBuffer* OpenGLSalBitmap::AcquireBuffer( BitmapAccessMode nMode )
         case 8:
             pBuffer->mnFormat = ScanlineFormat::N8BitPal;
             break;
-        case 16:
-        {
-            pBuffer->mnFormat = ScanlineFormat::N16BitTcMsbMask;
-            ColorMaskElement aRedMask(0x0000f800);
-            aRedMask.CalcMaskShift();
-            ColorMaskElement aGreenMask(0x000007e0);
-            aGreenMask.CalcMaskShift();
-            ColorMaskElement aBlueMask(0x0000001f);
-            aBlueMask.CalcMaskShift();
-            pBuffer->maColorMask  = ColorMask(aRedMask, aGreenMask, aBlueMask);
-            break;
-        }
         case 24:
         {
             pBuffer->mnFormat = ScanlineFormat::N24BitTcRgb;
@@ -833,6 +815,7 @@ BitmapBuffer* OpenGLSalBitmap::AcquireBuffer( BitmapAccessMode nMode )
             pBuffer->maColorMask  = ColorMask(aRedMask, aGreenMask, aBlueMask);
             break;
         }
+        default: assert(false);
     }
 
     return pBuffer;
@@ -912,7 +895,7 @@ bool OpenGLSalBitmap::Replace( const Color& rSearchColor, const Color& rReplaceC
     if( !pProgram )
         return false;
 
-    OpenGLTexture aNewTex = OpenGLTexture( mnWidth, mnHeight );
+    OpenGLTexture aNewTex( mnWidth, mnHeight );
     pFramebuffer = xContext->AcquireFramebuffer( aNewTex );
 
     pProgram->SetTexture( "sampler", maTexture );
@@ -936,7 +919,7 @@ bool OpenGLSalBitmap::ConvertToGreyscale()
 
     // avoid re-converting to 8bits.
     if ( mnBits == 8 && maPalette == Bitmap::GetGreyPalette(256) )
-        return false;
+        return true;
 
     OpenGLZone aZone;
     rtl::Reference<OpenGLContext> xContext = OpenGLContext::getVCLContext();
