@@ -27,7 +27,6 @@
 #include "JpegWriter.hxx"
 #include <vcl/bitmapaccess.hxx>
 #include <vcl/FilterConfigItem.hxx>
-#include <vcl/graphicfilter.hxx>
 #include <tools/helpers.hxx>
 #include <tools/stream.hxx>
 
@@ -123,15 +122,12 @@ JPEGWriter::JPEGWriter( SvStream& rStream, const css::uno::Sequence< css::beans:
 
     if ( pFilterData )
     {
-        int nArgs = pFilterData->getLength();
-        const css::beans::PropertyValue* pValues = pFilterData->getConstArray();
-        while( nArgs-- )
+        for( const auto& rValue : *pFilterData )
         {
-            if ( pValues->Name == "StatusIndicator" )
+            if ( rValue.Name == "StatusIndicator" )
             {
-                pValues->Value >>= mxStatusIndicator;
+                rValue.Value >>= mxStatusIndicator;
             }
-            pValues++;
         }
     }
 }
