@@ -19,10 +19,11 @@
 
 #include <graphic/Manager.hxx>
 #include <impgraph.hxx>
-#include <vcl/lazydelete.hxx>
-#include <vcl/svapp.hxx>
 #include <sal/log.hxx>
 
+#include <officecfg/Office/Common.hxx>
+#include <unotools/configmgr.hxx>
+
 using namespace css;
 
 namespace vcl
@@ -32,7 +33,7 @@ namespace graphic
 namespace
 {
 void setupConfigurationValuesIfPossible(sal_Int64& rMemoryLimit,
-                                        std::chrono::seconds& rAllowedIdleTime)
+                                        std::chrono::seconds& rAllowedIdleTime, bool& bSwapEnabled)
 {
     if (utl::ConfigManager::IsFuzzing())
         return;
@@ -44,6 +45,7 @@ void setupConfigurationValuesIfPossible(sal_Int64& rMemoryLimit,
         rMemoryLimit = Cache::GraphicManager::GraphicMemoryLimit::get();
         rAllowedIdleTime
             = std::chrono::seconds(Cache::GraphicManager::GraphicAllowedIdleTime::get());
+        bSwapEnabled = Cache::GraphicManager::GraphicSwappingEnabled::get();
     }
     catch (...)
     {
@@ -53,27 +55,34 @@ void setupConfigurationValuesIfPossible(sal_Int64& rMemoryLimit,
 
 Manager& Manager::get()
 {
-    static std::unique_ptr<Manager> gStaticManager(new Manager);
-    return *gStaticManager;
+    static Manager gStaticManager;
+    return gStaticManager;
 }
 
 Manager::Manager()
     : mnAllowedIdleTime(10)
+    , mbSwapEnabled(true)
     , mnMemoryLimit(300000000)
     , mnUsedSize(0)
     , maSwapOutTimer("graphic::Manager maSwapOutTimer")
 {
-    setupConfigurationValuesIfPossible(mnMemoryLimit, mnAllowedIdleTime);
+    setupConfigurationValuesIfPossible(mnMemoryLimit, mnAllowedIdleTime, mbSwapEnabled);
 
-    maSwapOutTimer.SetInvokeHandler(LINK(this, Manager, SwapOutTimerHandler));
-    maSwapOutTimer.SetTimeout(10000);
-    maSwapOutTimer.SetDebugName("graphic::Manager maSwapOutTimer");
-    maSwapOutTimer.Start();
+    if (mbSwapEnabled)
+    {
+        maSwapOutTimer.SetInvokeHandler(LINK(this, Manager, SwapOutTimerHandler));
+        maSwapOutTimer.SetTimeout(10000);
+        maSwapOutTimer.SetDebugName("graphic::Manager maSwapOutTimer");
+        maSwapOutTimer.Start();
+    }
 }
 
 void Manager::reduceGraphicMemory()
 {
-    std::lock_guard<std::recursive_mutex> aGuard(maMutex);
+    if (!mbSwapEnabled)
+        return;
+
+    std::scoped_lock<std::recursive_mutex> aGuard(maMutex);
 
     for (ImpGraphic* pEachImpGraphic : m_pImpGraphicList)
     {
@@ -105,7 +114,7 @@ sal_Int64 Manager::getGraphicSizeBytes(const ImpGraphic* pImpGraphic)
 
 IMPL_LINK(Manager, SwapOutTimerHandler, Timer*, pTimer, void)
 {
-    std::lock_guard<std::recursive_mutex> aGuard(maMutex);
+    std::scoped_lock<std::recursive_mutex> aGuard(maMutex);
 
     pTimer->Stop();
     reduceGraphicMemory();
@@ -115,7 +124,7 @@ IMPL_LINK(Manager, SwapOutTimerHandler, Timer*, pTimer, void)
 void Manager::registerGraphic(const std::shared_ptr<ImpGraphic>& pImpGraphic,
                               OUString const& /*rsContext*/)
 {
-    std::lock_guard<std::recursive_mutex> aGuard(maMutex);
+    std::scoped_lock<std::recursive_mutex> aGuard(maMutex);
 
     // make some space first
     if (mnUsedSize > mnMemoryLimit)
@@ -146,7 +155,7 @@ void Manager::registerGraphic(const std::shared_ptr<ImpGraphic>& pImpGraphic,
 
 void Manager::unregisterGraphic(ImpGraphic* pImpGraphic)
 {
-    std::lock_guard<std::recursive_mutex> aGuard(maMutex);
+    std::scoped_lock<std::recursive_mutex> aGuard(maMutex);
 
     mnUsedSize -= getGraphicSizeBytes(pImpGraphic);
     m_pImpGraphicList.erase(pImpGraphic);
@@ -210,21 +219,21 @@ std::shared_ptr<ImpGraphic> Manager::newInstance(const GraphicExternalLink& rGra
 
 void Manager::swappedIn(const ImpGraphic* pImpGraphic)
 {
-    std::lock_guard<std::recursive_mutex> aGuard(maMutex);
+    std::scoped_lock<std::recursive_mutex> aGuard(maMutex);
 
     mnUsedSize += getGraphicSizeBytes(pImpGraphic);
 }
 
 void Manager::swappedOut(const ImpGraphic* pImpGraphic)
 {
-    std::lock_guard<std::recursive_mutex> aGuard(maMutex);
+    std::scoped_lock<std::recursive_mutex> aGuard(maMutex);
 
     mnUsedSize -= getGraphicSizeBytes(pImpGraphic);
 }
 
 void Manager::changeExisting(const ImpGraphic* pImpGraphic, sal_Int64 nOldSizeBytes)
 {
-    std::lock_guard<std::recursive_mutex> aGuard(maMutex);
+    std::scoped_lock<std::recursive_mutex> aGuard(maMutex);
 
     mnUsedSize -= nOldSizeBytes;
     mnUsedSize += getGraphicSizeBytes(pImpGraphic);
