@@ -11,6 +11,11 @@
 #include <vcl/FilterConfigItem.hxx>
 #include "commonfuzzer.hxx"
 
+extern "C" void* SwCreateDialogFactory()
+{
+    return nullptr;
+}
+
 extern "C" bool TestImportDOCX(SvStream &rStream);
 
 extern "C" int LLVMFuzzerInitialize(int *argc, char ***argv)
