@@ -107,7 +107,7 @@ void StarOfficeWriterImportFilter::doRegisterHandlers(OdtGenerator& rGenerator)
 // XServiceInfo
 OUString SAL_CALL StarOfficeWriterImportFilter::getImplementationName()
 {
-    return OUString("org.libreoffice.comp.Writer.StarOfficeWriterImportFilter");
+    return "org.libreoffice.comp.Writer.StarOfficeWriterImportFilter";
 }
 
 sal_Bool SAL_CALL StarOfficeWriterImportFilter::supportsService(const OUString& rServiceName)
@@ -117,8 +117,7 @@ sal_Bool SAL_CALL StarOfficeWriterImportFilter::supportsService(const OUString&
 
 Sequence<OUString> SAL_CALL StarOfficeWriterImportFilter::getSupportedServiceNames()
 {
-    return Sequence<OUString>{ "com.sun.star.document.ImportFilter",
-                               "com.sun.star.document.ExtendedTypeDetection" };
+    return { "com.sun.star.document.ImportFilter", "com.sun.star.document.ExtendedTypeDetection" };
 }
 
 extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface*
