@@ -26,8 +26,10 @@
 #include "XMLTextListBlockContext.hxx"
 #include <xmloff/txtimp.hxx>
 #include <com/sun/star/container/XNameContainer.hpp>
+#include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/style/XStyle.hpp>
 #include <xmloff/xmlnumi.hxx>
+#include <xmloff/ProgressBarHelper.hxx>
 #include "XMLTextListItemContext.hxx"
 
 
@@ -141,7 +143,7 @@ SvXMLImportContextRef XMLTextListItemContext::CreateChildContext(
     {
     case XML_TOK_TEXT_H:
         bHeading = true;
-        SAL_FALLTHROUGH;
+        [[fallthrough]];
     case XML_TOK_TEXT_P:
         pContext = new XMLParaContext( GetImport(),
                                        nPrefix, rLocalName,
