@@ -31,8 +31,6 @@ using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::xml::sax;
 using namespace ::xmloff::token;
 
-TYPEINIT1( XMLControlOASISTransformerContext, XMLTransformerContext );
-
 XMLControlOASISTransformerContext::XMLControlOASISTransformerContext(
         XMLTransformerBase& rImp,
         const OUString& rQName,
@@ -44,10 +42,6 @@ XMLControlOASISTransformerContext::XMLControlOASISTransformerContext(
 {
 }
 
-XMLControlOASISTransformerContext::~XMLControlOASISTransformerContext()
-{
-}
-
 void XMLControlOASISTransformerContext::StartElement(
     const Reference< XAttributeList >& rAttrList )
 {
@@ -57,12 +51,12 @@ void XMLControlOASISTransformerContext::StartElement(
     OSL_ENSURE( pActions, "go no actions" );
 
     Reference< XAttributeList > xAttrList( rAttrList );
-    XMLMutableAttributeList *pMutableAttrList = 0;
+    XMLMutableAttributeList *pMutableAttrList = nullptr;
 //      GetTransformer().ProcessAttrList( xAttrList, OOO_SHAPE_ACTIONS,
 //                                        sal_True );
 
     XMLMutableAttributeList *pControlMutableAttrList =
-        m_bCreateControl ? new XMLMutableAttributeList : 0;
+        m_bCreateControl ? new XMLMutableAttributeList : nullptr;
     Reference< XAttributeList > xControlAttrList( pControlMutableAttrList );
 
     sal_Int16 nAttrCount = xAttrList.is() ? xAttrList->getLength() : 0;
@@ -76,7 +70,7 @@ void XMLControlOASISTransformerContext::StartElement(
         XMLTransformerActions::key_type aKey( nPrefix, aLocalName );
         XMLTransformerActions::const_iterator aIter =
             pActions->find( aKey );
-        if( !(aIter == pActions->end() ) )
+        if( aIter != pActions->end() )
         {
             if( !pMutableAttrList )
             {
