@@ -19,19 +19,18 @@
 
 #include <sal/config.h>
 
-#include <unoservices.hxx>
 #include "xmlbas_export.hxx"
 #include <sal/log.hxx>
 #include <xmlscript/xmlns.h>
 #include <xmlscript/xml_helper.hxx>
 #include <com/sun/star/beans/XPropertySet.hpp>
-#include <com/sun/star/lang/XMultiComponentFactory.hpp>
 #include <com/sun/star/script/XLibraryContainer2.hpp>
 #include <com/sun/star/script/XLibraryContainerPassword.hpp>
 #include <com/sun/star/document/XEmbeddedScripts.hpp>
+#include <com/sun/star/uno/XComponentContext.hpp>
 #include <com/sun/star/xml/sax/SAXException.hpp>
-#include <cppuhelper/implementationentry.hxx>
 #include <cppuhelper/supportsservice.hxx>
+#include <tools/diagnose_ex.h>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::lang;
@@ -118,8 +117,7 @@ sal_Bool XMLBasicExporterBase::filter( const Sequence< beans::PropertyValue >& /
                 }
 
                 // ooo/script:libraries element
-                OUString aLibContElementName( aPrefix );
-                aLibContElementName += ":libraries";
+                OUString aLibContElementName = aPrefix + ":libraries";
                 XMLElement* pLibContElement = new XMLElement( aLibContElementName );
                 Reference< xml::sax::XAttributeList > xLibContAttribs( pLibContElement );
 
@@ -152,7 +150,7 @@ sal_Bool XMLBasicExporterBase::filter( const Sequence< beans::PropertyValue >& /
 
                 if ( xLibContainer.is() )
                 {
-                    Sequence< OUString > aLibNames = xLibContainer->getElementNames();
+                    const Sequence< OUString > aLibNames = xLibContainer->getElementNames();
                     for ( const OUString& rLibName : aLibNames )
                     {
                         if ( xLibContainer->hasByName( rLibName ) )
@@ -162,11 +160,9 @@ sal_Bool XMLBasicExporterBase::filter( const Sequence< beans::PropertyValue >& /
                             if ( xLibContainer->isLibraryLink( rLibName ) )
                             {
                                 // ooo/script:library-linked element
-                                OUString aLibElementName( aPrefix );
-                                aLibElementName +=  ":library-linked";
+                                OUString aLibElementName = aPrefix + ":library-linked";
                                 XMLElement* pLibElement = new XMLElement( aLibElementName );
-                                Reference< xml::sax::XAttributeList > xLibAttribs;
-                                xLibAttribs = static_cast< xml::sax::XAttributeList* >( pLibElement );
+                                Reference< xml::sax::XAttributeList > xLibAttribs = static_cast< xml::sax::XAttributeList* >( pLibElement );
 
                                 // ooo/script:name attribute
                                 pLibElement->addAttribute( aPrefix + ":name", rLibName );
@@ -198,11 +194,9 @@ sal_Bool XMLBasicExporterBase::filter( const Sequence< beans::PropertyValue >& /
                             else
                             {
                                 // ooo/script:library-embedded element
-                                OUString aLibElementName( aPrefix );
-                                aLibElementName += ":library-embedded";
+                                OUString aLibElementName = aPrefix + ":library-embedded";
                                 XMLElement* pLibElement = new XMLElement( aLibElementName );
-                                Reference< xml::sax::XAttributeList > xLibAttribs;
-                                xLibAttribs = static_cast< xml::sax::XAttributeList* >( pLibElement );
+                                Reference< xml::sax::XAttributeList > xLibAttribs = static_cast< xml::sax::XAttributeList* >( pLibElement );
 
                                 // ooo/script:name attribute
                                 pLibElement->addAttribute( aPrefix + ":name", rLibName );
@@ -230,17 +224,15 @@ sal_Bool XMLBasicExporterBase::filter( const Sequence< beans::PropertyValue >& /
 
                                 if ( xLib.is() )
                                 {
-                                    Sequence< OUString > aModNames = xLib->getElementNames();
+                                    const Sequence< OUString > aModNames = xLib->getElementNames();
                                     for ( const OUString& rModName : aModNames )
                                     {
                                         if ( xLib->hasByName( rModName ) )
                                         {
                                             // ooo/script:module element
-                                            OUString aModElementName( aPrefix );
-                                            aModElementName += ":module";
+                                            OUString aModElementName = aPrefix + ":module";
                                             XMLElement* pModElement = new XMLElement( aModElementName );
-                                            Reference< xml::sax::XAttributeList > xModAttribs;
-                                            xModAttribs = static_cast< xml::sax::XAttributeList* >( pModElement );
+                                            Reference< xml::sax::XAttributeList > xModAttribs = static_cast< xml::sax::XAttributeList* >( pModElement );
 
                                             // ooo/script:name attribute
                                             pModElement->addAttribute( aPrefix + ":name", rModName );
@@ -250,11 +242,9 @@ sal_Bool XMLBasicExporterBase::filter( const Sequence< beans::PropertyValue >& /
                                             m_xHandler->startElement( aModElementName, xModAttribs );
 
                                             // ooo/script:source-code element
-                                            OUString aSourceElementName( aPrefix );
-                                            aSourceElementName += ":source-code";
+                                            OUString aSourceElementName = aPrefix + ":source-code";
                                             XMLElement* pSourceElement = new XMLElement( aSourceElementName );
-                                            Reference< xml::sax::XAttributeList > xSourceAttribs;
-                                            xSourceAttribs = static_cast< xml::sax::XAttributeList* >( pSourceElement );
+                                            Reference< xml::sax::XAttributeList > xSourceAttribs = static_cast< xml::sax::XAttributeList* >( pSourceElement );
 
                                             // <ooo/script:source-code...
                                             m_xHandler->ignorableWhitespace( OUString() );
@@ -294,24 +284,24 @@ sal_Bool XMLBasicExporterBase::filter( const Sequence< beans::PropertyValue >& /
                 m_xHandler->endDocument();
             }
         }
-        catch ( const container::NoSuchElementException& e )
+        catch ( const container::NoSuchElementException& )
         {
-            SAL_INFO("xmlscript.xmlflat", "XMLBasicExporterBase::filter: caught NoSuchElementException reason " << e );
+            TOOLS_INFO_EXCEPTION("xmlscript.xmlflat", "XMLBasicExporterBase::filter" );
             bReturn = false;
         }
-        catch ( const lang::IllegalArgumentException& e )
+        catch ( const lang::IllegalArgumentException& )
         {
-            SAL_INFO("xmlscript.xmlflat", "XMLBasicExporterBase::filter: caught IllegalArgumentException reason " << e );
+            TOOLS_INFO_EXCEPTION("xmlscript.xmlflat", "XMLBasicExporterBase::filter" );
             bReturn = false;
         }
-        catch ( const lang::WrappedTargetException& e )
+        catch ( const lang::WrappedTargetException& )
         {
-            SAL_INFO("xmlscript.xmlflat", "XMLBasicExporterBase::filter: caught WrappedTargetException reason " << e );
+            TOOLS_INFO_EXCEPTION("xmlscript.xmlflat", "XMLBasicExporterBase::filter:" );
             bReturn = false;
         }
-        catch ( const xml::sax::SAXException& e )
+        catch ( const xml::sax::SAXException& )
         {
-            SAL_INFO("xmlscript.xmlflat", "XMLBasicExporterBase::filter: caught SAXException reason " << e );
+            TOOLS_INFO_EXCEPTION("xmlscript.xmlflat", "XMLBasicExporterBase::filter:" );
             bReturn = false;
         }
 
@@ -340,7 +330,7 @@ sal_Bool XMLBasicExporterBase::filter( const Sequence< beans::PropertyValue >& /
 
     OUString XMLBasicExporter::getImplementationName(  )
     {
-        return OUString( "com.sun.star.comp.xmlscript.XMLBasicExporter" );
+        return "com.sun.star.comp.xmlscript.XMLBasicExporter";
     }
 
     Sequence< OUString > XMLBasicExporter::getSupportedServiceNames(  )
@@ -364,7 +354,7 @@ sal_Bool XMLBasicExporterBase::filter( const Sequence< beans::PropertyValue >& /
 
     OUString XMLOasisBasicExporter::getImplementationName(  )
     {
-        return OUString( "com.sun.star.comp.xmlscript.XMLOasisBasicExporter" );
+        return "com.sun.star.comp.xmlscript.XMLOasisBasicExporter";
     }
 
     Sequence< OUString > XMLOasisBasicExporter::getSupportedServiceNames(  )
